# File generated by lib_pypy/_cffi_ssl/tools/make_ssl_data.py
# Generated on 2021-11-07T08:11:00.061651

from _pypy_openssl import ffi, lib
_lib_codes = [
    ("ASN1", lib.ERR_LIB_ASN1),
    ("ASYNC", lib.ERR_LIB_ASYNC),
    ("BIO", lib.ERR_LIB_BIO),
    ("BN", lib.ERR_LIB_BN),
    ("BUF", lib.ERR_LIB_BUF),
    ("CMP", lib.ERR_LIB_CMP),
    ("CMS", lib.ERR_LIB_CMS),
    ("COMP", lib.ERR_LIB_COMP),
    ("CONF", lib.ERR_LIB_CONF),
    ("CRMF", lib.ERR_LIB_CRMF),
    ("CRYPTO", lib.ERR_LIB_CRYPTO),
    ("CT", lib.ERR_LIB_CT),
    ("DH", lib.ERR_LIB_DH),
    ("DSA", lib.ERR_LIB_DSA),
    ("DSO", lib.ERR_LIB_DSO),
    ("EC", lib.ERR_LIB_EC),
    ("ECDH", lib.ERR_LIB_ECDH),
    ("ECDSA", lib.ERR_LIB_ECDSA),
    ("ENGINE", lib.ERR_LIB_ENGINE),
    ("ESS", lib.ERR_LIB_ESS),
    ("EVP", lib.ERR_LIB_EVP),
    ("FIPS", lib.ERR_LIB_FIPS),
    ("HMAC", lib.ERR_LIB_HMAC),
    ("HTTP", lib.ERR_LIB_HTTP),
    ("KDF", lib.ERR_LIB_KDF),
    ("MASK", lib.ERR_LIB_MASK),
    ("NONE", lib.ERR_LIB_NONE),
    ("OBJ", lib.ERR_LIB_OBJ),
    ("OCSP", lib.ERR_LIB_OCSP),
    ("OFFSET", lib.ERR_LIB_OFFSET),
    ("OSSL_DECODER", lib.ERR_LIB_OSSL_DECODER),
    ("OSSL_ENCODER", lib.ERR_LIB_OSSL_ENCODER),
    ("OSSL_STORE", lib.ERR_LIB_OSSL_STORE),
    ("PEM", lib.ERR_LIB_PEM),
    ("PKCS12", lib.ERR_LIB_PKCS12),
    ("PKCS7", lib.ERR_LIB_PKCS7),
    ("PROP", lib.ERR_LIB_PROP),
    ("PROV", lib.ERR_LIB_PROV),
    ("RAND", lib.ERR_LIB_RAND),
    ("RSA", lib.ERR_LIB_RSA),
    ("SM2", lib.ERR_LIB_SM2),
    ("SSL", lib.ERR_LIB_SSL),
    ("SYS", lib.ERR_LIB_SYS),
    ("TS", lib.ERR_LIB_TS),
    ("UI", lib.ERR_LIB_UI),
    ("USER", lib.ERR_LIB_USER),
    ("X509", lib.ERR_LIB_X509),
    ("X509V3", lib.ERR_LIB_X509V3),
]


_error_codes = [
    ("ADDING_OBJECT", lib.ERR_LIB_ASN1, 171),
    ("ASN1_PARSE_ERROR", lib.ERR_LIB_ASN1, 203),
    ("ASN1_SIG_PARSE_ERROR", lib.ERR_LIB_ASN1, 204),
    ("AUX_ERROR", lib.ERR_LIB_ASN1, 100),
    ("BAD_OBJECT_HEADER", lib.ERR_LIB_ASN1, 102),
    ("BAD_TEMPLATE", lib.ERR_LIB_ASN1, 230),
    ("BMPSTRING_IS_WRONG_LENGTH", lib.ERR_LIB_ASN1, 214),
    ("BN_LIB", lib.ERR_LIB_ASN1, 105),
    ("BOOLEAN_IS_WRONG_LENGTH", lib.ERR_LIB_ASN1, 106),
    ("BUFFER_TOO_SMALL", lib.ERR_LIB_ASN1, 107),
    ("CIPHER_HAS_NO_OBJECT_IDENTIFIER", lib.ERR_LIB_ASN1, 108),
    ("CONTEXT_NOT_INITIALISED", lib.ERR_LIB_ASN1, 217),
    ("DATA_IS_WRONG", lib.ERR_LIB_ASN1, 109),
    ("DECODE_ERROR", lib.ERR_LIB_ASN1, 110),
    ("DEPTH_EXCEEDED", lib.ERR_LIB_ASN1, 174),
    ("DIGEST_AND_KEY_TYPE_NOT_SUPPORTED", lib.ERR_LIB_ASN1, 198),
    ("ENCODE_ERROR", lib.ERR_LIB_ASN1, 112),
    ("ERROR_GETTING_TIME", lib.ERR_LIB_ASN1, 173),
    ("ERROR_LOADING_SECTION", lib.ERR_LIB_ASN1, 172),
    ("ERROR_SETTING_CIPHER_PARAMS", lib.ERR_LIB_ASN1, 114),
    ("EXPECTING_AN_INTEGER", lib.ERR_LIB_ASN1, 115),
    ("EXPECTING_AN_OBJECT", lib.ERR_LIB_ASN1, 116),
    ("EXPLICIT_LENGTH_MISMATCH", lib.ERR_LIB_ASN1, 119),
    ("EXPLICIT_TAG_NOT_CONSTRUCTED", lib.ERR_LIB_ASN1, 120),
    ("FIELD_MISSING", lib.ERR_LIB_ASN1, 121),
    ("FIRST_NUM_TOO_LARGE", lib.ERR_LIB_ASN1, 122),
    ("HEADER_TOO_LONG", lib.ERR_LIB_ASN1, 123),
    ("ILLEGAL_BITSTRING_FORMAT", lib.ERR_LIB_ASN1, 175),
    ("ILLEGAL_BOOLEAN", lib.ERR_LIB_ASN1, 176),
    ("ILLEGAL_CHARACTERS", lib.ERR_LIB_ASN1, 124),
    ("ILLEGAL_FORMAT", lib.ERR_LIB_ASN1, 177),
    ("ILLEGAL_HEX", lib.ERR_LIB_ASN1, 178),
    ("ILLEGAL_IMPLICIT_TAG", lib.ERR_LIB_ASN1, 179),
    ("ILLEGAL_INTEGER", lib.ERR_LIB_ASN1, 180),
    ("ILLEGAL_NEGATIVE_VALUE", lib.ERR_LIB_ASN1, 226),
    ("ILLEGAL_NESTED_TAGGING", lib.ERR_LIB_ASN1, 181),
    ("ILLEGAL_NULL", lib.ERR_LIB_ASN1, 125),
    ("ILLEGAL_NULL_VALUE", lib.ERR_LIB_ASN1, 182),
    ("ILLEGAL_OBJECT", lib.ERR_LIB_ASN1, 183),
    ("ILLEGAL_OPTIONAL_ANY", lib.ERR_LIB_ASN1, 126),
    ("ILLEGAL_OPTIONS_ON_ITEM_TEMPLATE", lib.ERR_LIB_ASN1, 170),
    ("ILLEGAL_PADDING", lib.ERR_LIB_ASN1, 221),
    ("ILLEGAL_TAGGED_ANY", lib.ERR_LIB_ASN1, 127),
    ("ILLEGAL_TIME_VALUE", lib.ERR_LIB_ASN1, 184),
    ("ILLEGAL_ZERO_CONTENT", lib.ERR_LIB_ASN1, 222),
    ("INTEGER_NOT_ASCII_FORMAT", lib.ERR_LIB_ASN1, 185),
    ("INTEGER_TOO_LARGE_FOR_LONG", lib.ERR_LIB_ASN1, 128),
    ("INVALID_BIT_STRING_BITS_LEFT", lib.ERR_LIB_ASN1, 220),
    ("INVALID_BMPSTRING_LENGTH", lib.ERR_LIB_ASN1, 129),
    ("INVALID_DIGIT", lib.ERR_LIB_ASN1, 130),
    ("INVALID_MIME_TYPE", lib.ERR_LIB_ASN1, 205),
    ("INVALID_MODIFIER", lib.ERR_LIB_ASN1, 186),
    ("INVALID_NUMBER", lib.ERR_LIB_ASN1, 187),
    ("INVALID_OBJECT_ENCODING", lib.ERR_LIB_ASN1, 216),
    ("INVALID_SCRYPT_PARAMETERS", lib.ERR_LIB_ASN1, 227),
    ("INVALID_SEPARATOR", lib.ERR_LIB_ASN1, 131),
    ("INVALID_STRING_TABLE_VALUE", lib.ERR_LIB_ASN1, 218),
    ("INVALID_UNIVERSALSTRING_LENGTH", lib.ERR_LIB_ASN1, 133),
    ("INVALID_UTF8STRING", lib.ERR_LIB_ASN1, 134),
    ("INVALID_VALUE", lib.ERR_LIB_ASN1, 219),
    ("LENGTH_TOO_LONG", lib.ERR_LIB_ASN1, 231),
    ("LIST_ERROR", lib.ERR_LIB_ASN1, 188),
    ("MIME_NO_CONTENT_TYPE", lib.ERR_LIB_ASN1, 206),
    ("MIME_PARSE_ERROR", lib.ERR_LIB_ASN1, 207),
    ("MIME_SIG_PARSE_ERROR", lib.ERR_LIB_ASN1, 208),
    ("MISSING_EOC", lib.ERR_LIB_ASN1, 137),
    ("MISSING_SECOND_NUMBER", lib.ERR_LIB_ASN1, 138),
    ("MISSING_VALUE", lib.ERR_LIB_ASN1, 189),
    ("MSTRING_NOT_UNIVERSAL", lib.ERR_LIB_ASN1, 139),
    ("MSTRING_WRONG_TAG", lib.ERR_LIB_ASN1, 140),
    ("NESTED_ASN1_STRING", lib.ERR_LIB_ASN1, 197),
    ("NESTED_TOO_DEEP", lib.ERR_LIB_ASN1, 201),
    ("NON_HEX_CHARACTERS", lib.ERR_LIB_ASN1, 141),
    ("NOT_ASCII_FORMAT", lib.ERR_LIB_ASN1, 190),
    ("NOT_ENOUGH_DATA", lib.ERR_LIB_ASN1, 142),
    ("NO_CONTENT_TYPE", lib.ERR_LIB_ASN1, 209),
    ("NO_MATCHING_CHOICE_TYPE", lib.ERR_LIB_ASN1, 143),
    ("NO_MULTIPART_BODY_FAILURE", lib.ERR_LIB_ASN1, 210),
    ("NO_MULTIPART_BOUNDARY", lib.ERR_LIB_ASN1, 211),
    ("NO_SIG_CONTENT_TYPE", lib.ERR_LIB_ASN1, 212),
    ("NULL_IS_WRONG_LENGTH", lib.ERR_LIB_ASN1, 144),
    ("OBJECT_NOT_ASCII_FORMAT", lib.ERR_LIB_ASN1, 191),
    ("ODD_NUMBER_OF_CHARS", lib.ERR_LIB_ASN1, 145),
    ("SECOND_NUMBER_TOO_LARGE", lib.ERR_LIB_ASN1, 147),
    ("SEQUENCE_LENGTH_MISMATCH", lib.ERR_LIB_ASN1, 148),
    ("SEQUENCE_NOT_CONSTRUCTED", lib.ERR_LIB_ASN1, 149),
    ("SEQUENCE_OR_SET_NEEDS_CONFIG", lib.ERR_LIB_ASN1, 192),
    ("SHORT_LINE", lib.ERR_LIB_ASN1, 150),
    ("SIG_INVALID_MIME_TYPE", lib.ERR_LIB_ASN1, 213),
    ("STREAMING_NOT_SUPPORTED", lib.ERR_LIB_ASN1, 202),
    ("STRING_TOO_LONG", lib.ERR_LIB_ASN1, 151),
    ("STRING_TOO_SHORT", lib.ERR_LIB_ASN1, 152),
    ("THE_ASN1_OBJECT_IDENTIFIER_IS_NOT_KNOWN_FOR_THIS_MD", lib.ERR_LIB_ASN1, 154),
    ("TIME_NOT_ASCII_FORMAT", lib.ERR_LIB_ASN1, 193),
    ("TOO_LARGE", lib.ERR_LIB_ASN1, 223),
    ("TOO_LONG", lib.ERR_LIB_ASN1, 155),
    ("TOO_SMALL", lib.ERR_LIB_ASN1, 224),
    ("TYPE_NOT_CONSTRUCTED", lib.ERR_LIB_ASN1, 156),
    ("TYPE_NOT_PRIMITIVE", lib.ERR_LIB_ASN1, 195),
    ("UNEXPECTED_EOC", lib.ERR_LIB_ASN1, 159),
    ("UNIVERSALSTRING_IS_WRONG_LENGTH", lib.ERR_LIB_ASN1, 215),
    ("UNKNOWN_DIGEST", lib.ERR_LIB_ASN1, 229),
    ("UNKNOWN_FORMAT", lib.ERR_LIB_ASN1, 160),
    ("UNKNOWN_MESSAGE_DIGEST_ALGORITHM", lib.ERR_LIB_ASN1, 161),
    ("UNKNOWN_OBJECT_TYPE", lib.ERR_LIB_ASN1, 162),
    ("UNKNOWN_PUBLIC_KEY_TYPE", lib.ERR_LIB_ASN1, 163),
    ("UNKNOWN_SIGNATURE_ALGORITHM", lib.ERR_LIB_ASN1, 199),
    ("UNKNOWN_TAG", lib.ERR_LIB_ASN1, 194),
    ("UNSUPPORTED_ANY_DEFINED_BY_TYPE", lib.ERR_LIB_ASN1, 164),
    ("UNSUPPORTED_CIPHER", lib.ERR_LIB_ASN1, 228),
    ("UNSUPPORTED_PUBLIC_KEY_TYPE", lib.ERR_LIB_ASN1, 167),
    ("UNSUPPORTED_TYPE", lib.ERR_LIB_ASN1, 196),
    ("WRONG_INTEGER_TYPE", lib.ERR_LIB_ASN1, 225),
    ("WRONG_PUBLIC_KEY_TYPE", lib.ERR_LIB_ASN1, 200),
    ("WRONG_TAG", lib.ERR_LIB_ASN1, 168),
    ("FAILED_TO_SET_POOL", lib.ERR_LIB_ASYNC, 101),
    ("FAILED_TO_SWAP_CONTEXT", lib.ERR_LIB_ASYNC, 102),
    ("INIT_FAILED", lib.ERR_LIB_ASYNC, 105),
    ("INVALID_POOL_SIZE", lib.ERR_LIB_ASYNC, 103),
    ("ACCEPT_ERROR", lib.ERR_LIB_BIO, 100),
    ("ADDRINFO_ADDR_IS_NOT_AF_INET", lib.ERR_LIB_BIO, 141),
    ("AMBIGUOUS_HOST_OR_SERVICE", lib.ERR_LIB_BIO, 129),
    ("BAD_FOPEN_MODE", lib.ERR_LIB_BIO, 101),
    ("BROKEN_PIPE", lib.ERR_LIB_BIO, 124),
    ("CONNECT_ERROR", lib.ERR_LIB_BIO, 103),
    ("CONNECT_TIMEOUT", lib.ERR_LIB_BIO, 147),
    ("GETHOSTBYNAME_ADDR_IS_NOT_AF_INET", lib.ERR_LIB_BIO, 107),
    ("GETSOCKNAME_ERROR", lib.ERR_LIB_BIO, 132),
    ("GETSOCKNAME_TRUNCATED_ADDRESS", lib.ERR_LIB_BIO, 133),
    ("GETTING_SOCKTYPE", lib.ERR_LIB_BIO, 134),
    ("INVALID_ARGUMENT", lib.ERR_LIB_BIO, 125),
    ("INVALID_SOCKET", lib.ERR_LIB_BIO, 135),
    ("IN_USE", lib.ERR_LIB_BIO, 123),
    ("LENGTH_TOO_LONG", lib.ERR_LIB_BIO, 102),
    ("LISTEN_V6_ONLY", lib.ERR_LIB_BIO, 136),
    ("LOOKUP_RETURNED_NOTHING", lib.ERR_LIB_BIO, 142),
    ("MALFORMED_HOST_OR_SERVICE", lib.ERR_LIB_BIO, 130),
    ("NBIO_CONNECT_ERROR", lib.ERR_LIB_BIO, 110),
    ("NO_ACCEPT_ADDR_OR_SERVICE_SPECIFIED", lib.ERR_LIB_BIO, 143),
    ("NO_HOSTNAME_OR_SERVICE_SPECIFIED", lib.ERR_LIB_BIO, 144),
    ("NO_PORT_DEFINED", lib.ERR_LIB_BIO, 113),
    ("NO_SUCH_FILE", lib.ERR_LIB_BIO, 128),
    ("TRANSFER_ERROR", lib.ERR_LIB_BIO, 104),
    ("TRANSFER_TIMEOUT", lib.ERR_LIB_BIO, 105),
    ("UNABLE_TO_BIND_SOCKET", lib.ERR_LIB_BIO, 117),
    ("UNABLE_TO_CREATE_SOCKET", lib.ERR_LIB_BIO, 118),
    ("UNABLE_TO_KEEPALIVE", lib.ERR_LIB_BIO, 137),
    ("UNABLE_TO_LISTEN_SOCKET", lib.ERR_LIB_BIO, 119),
    ("UNABLE_TO_NODELAY", lib.ERR_LIB_BIO, 138),
    ("UNABLE_TO_REUSEADDR", lib.ERR_LIB_BIO, 139),
    ("UNAVAILABLE_IP_FAMILY", lib.ERR_LIB_BIO, 145),
    ("UNINITIALIZED", lib.ERR_LIB_BIO, 120),
    ("UNKNOWN_INFO_TYPE", lib.ERR_LIB_BIO, 140),
    ("UNSUPPORTED_IP_FAMILY", lib.ERR_LIB_BIO, 146),
    ("UNSUPPORTED_METHOD", lib.ERR_LIB_BIO, 121),
    ("UNSUPPORTED_PROTOCOL_FAMILY", lib.ERR_LIB_BIO, 131),
    ("WRITE_TO_READ_ONLY_BIO", lib.ERR_LIB_BIO, 126),
    ("WSASTARTUP", lib.ERR_LIB_BIO, 122),
    ("ARG2_LT_ARG3", lib.ERR_LIB_BN, 100),
    ("BAD_RECIPROCAL", lib.ERR_LIB_BN, 101),
    ("BIGNUM_TOO_LONG", lib.ERR_LIB_BN, 114),
    ("BITS_TOO_SMALL", lib.ERR_LIB_BN, 118),
    ("CALLED_WITH_EVEN_MODULUS", lib.ERR_LIB_BN, 102),
    ("DIV_BY_ZERO", lib.ERR_LIB_BN, 103),
    ("ENCODING_ERROR", lib.ERR_LIB_BN, 104),
    ("EXPAND_ON_STATIC_BIGNUM_DATA", lib.ERR_LIB_BN, 105),
    ("INPUT_NOT_REDUCED", lib.ERR_LIB_BN, 110),
    ("INVALID_LENGTH", lib.ERR_LIB_BN, 106),
    ("INVALID_RANGE", lib.ERR_LIB_BN, 115),
    ("INVALID_SHIFT", lib.ERR_LIB_BN, 119),
    ("NOT_A_SQUARE", lib.ERR_LIB_BN, 111),
    ("NOT_INITIALIZED", lib.ERR_LIB_BN, 107),
    ("NO_INVERSE", lib.ERR_LIB_BN, 108),
    ("NO_SOLUTION", lib.ERR_LIB_BN, 116),
    ("NO_SUITABLE_DIGEST", lib.ERR_LIB_BN, 120),
    ("PRIVATE_KEY_TOO_LARGE", lib.ERR_LIB_BN, 117),
    ("P_IS_NOT_PRIME", lib.ERR_LIB_BN, 112),
    ("TOO_MANY_ITERATIONS", lib.ERR_LIB_BN, 113),
    ("TOO_MANY_TEMPORARY_VARIABLES", lib.ERR_LIB_BN, 109),
    ("ALGORITHM_NOT_SUPPORTED", lib.ERR_LIB_CMP, 139),
    ("BAD_CHECKAFTER_IN_POLLREP", lib.ERR_LIB_CMP, 167),
    ("BAD_REQUEST_ID", lib.ERR_LIB_CMP, 108),
    ("CERTHASH_UNMATCHED", lib.ERR_LIB_CMP, 156),
    ("CERTID_NOT_FOUND", lib.ERR_LIB_CMP, 109),
    ("CERTIFICATE_NOT_ACCEPTED", lib.ERR_LIB_CMP, 169),
    ("CERTIFICATE_NOT_FOUND", lib.ERR_LIB_CMP, 112),
    ("CERTREQMSG_NOT_FOUND", lib.ERR_LIB_CMP, 157),
    ("CERTRESPONSE_NOT_FOUND", lib.ERR_LIB_CMP, 113),
    ("CERT_AND_KEY_DO_NOT_MATCH", lib.ERR_LIB_CMP, 114),
    ("CHECKAFTER_OUT_OF_RANGE", lib.ERR_LIB_CMP, 181),
    ("ENCOUNTERED_KEYUPDATEWARNING", lib.ERR_LIB_CMP, 176),
    ("ENCOUNTERED_WAITING", lib.ERR_LIB_CMP, 162),
    ("ERROR_CALCULATING_PROTECTION", lib.ERR_LIB_CMP, 115),
    ("ERROR_CREATING_CERTCONF", lib.ERR_LIB_CMP, 116),
    ("ERROR_CREATING_CERTREP", lib.ERR_LIB_CMP, 117),
    ("ERROR_CREATING_CERTREQ", lib.ERR_LIB_CMP, 163),
    ("ERROR_CREATING_ERROR", lib.ERR_LIB_CMP, 118),
    ("ERROR_CREATING_GENM", lib.ERR_LIB_CMP, 119),
    ("ERROR_CREATING_GENP", lib.ERR_LIB_CMP, 120),
    ("ERROR_CREATING_PKICONF", lib.ERR_LIB_CMP, 122),
    ("ERROR_CREATING_POLLREP", lib.ERR_LIB_CMP, 123),
    ("ERROR_CREATING_POLLREQ", lib.ERR_LIB_CMP, 124),
    ("ERROR_CREATING_RP", lib.ERR_LIB_CMP, 125),
    ("ERROR_CREATING_RR", lib.ERR_LIB_CMP, 126),
    ("ERROR_PARSING_PKISTATUS", lib.ERR_LIB_CMP, 107),
    ("ERROR_PROCESSING_MESSAGE", lib.ERR_LIB_CMP, 158),
    ("ERROR_PROTECTING_MESSAGE", lib.ERR_LIB_CMP, 127),
    ("ERROR_SETTING_CERTHASH", lib.ERR_LIB_CMP, 128),
    ("ERROR_UNEXPECTED_CERTCONF", lib.ERR_LIB_CMP, 160),
    ("ERROR_VALIDATING_PROTECTION", lib.ERR_LIB_CMP, 140),
    ("ERROR_VALIDATING_SIGNATURE", lib.ERR_LIB_CMP, 171),
    ("FAILED_BUILDING_OWN_CHAIN", lib.ERR_LIB_CMP, 164),
    ("FAILED_EXTRACTING_PUBKEY", lib.ERR_LIB_CMP, 141),
    ("FAILURE_OBTAINING_RANDOM", lib.ERR_LIB_CMP, 110),
    ("FAIL_INFO_OUT_OF_RANGE", lib.ERR_LIB_CMP, 129),
    ("INVALID_ARGS", lib.ERR_LIB_CMP, 100),
    ("INVALID_OPTION", lib.ERR_LIB_CMP, 174),
    ("MISSING_CERTID", lib.ERR_LIB_CMP, 165),
    ("MISSING_KEY_INPUT_FOR_CREATING_PROTECTION", lib.ERR_LIB_CMP, 130),
    ("MISSING_KEY_USAGE_DIGITALSIGNATURE", lib.ERR_LIB_CMP, 142),
    ("MISSING_P10CSR", lib.ERR_LIB_CMP, 121),
    ("MISSING_PBM_SECRET", lib.ERR_LIB_CMP, 166),
    ("MISSING_PRIVATE_KEY", lib.ERR_LIB_CMP, 131),
    ("MISSING_PROTECTION", lib.ERR_LIB_CMP, 143),
    ("MISSING_REFERENCE_CERT", lib.ERR_LIB_CMP, 168),
    ("MISSING_SENDER_IDENTIFICATION", lib.ERR_LIB_CMP, 111),
    ("MISSING_TRUST_STORE", lib.ERR_LIB_CMP, 144),
    ("MULTIPLE_REQUESTS_NOT_SUPPORTED", lib.ERR_LIB_CMP, 161),
    ("MULTIPLE_RESPONSES_NOT_SUPPORTED", lib.ERR_LIB_CMP, 170),
    ("MULTIPLE_SAN_SOURCES", lib.ERR_LIB_CMP, 102),
    ("NO_STDIO", lib.ERR_LIB_CMP, 194),
    ("NO_SUITABLE_SENDER_CERT", lib.ERR_LIB_CMP, 145),
    ("NULL_ARGUMENT", lib.ERR_LIB_CMP, 103),
    ("PKIBODY_ERROR", lib.ERR_LIB_CMP, 146),
    ("PKISTATUSINFO_NOT_FOUND", lib.ERR_LIB_CMP, 132),
    ("POLLING_FAILED", lib.ERR_LIB_CMP, 172),
    ("POTENTIALLY_INVALID_CERTIFICATE", lib.ERR_LIB_CMP, 147),
    ("RECEIVED_ERROR", lib.ERR_LIB_CMP, 180),
    ("RECIPNONCE_UNMATCHED", lib.ERR_LIB_CMP, 148),
    ("REQUEST_NOT_ACCEPTED", lib.ERR_LIB_CMP, 149),
    ("REQUEST_REJECTED_BY_SERVER", lib.ERR_LIB_CMP, 182),
    ("SENDER_GENERALNAME_TYPE_NOT_SUPPORTED", lib.ERR_LIB_CMP, 150),
    ("SRVCERT_DOES_NOT_VALIDATE_MSG", lib.ERR_LIB_CMP, 151),
    ("TOTAL_TIMEOUT", lib.ERR_LIB_CMP, 184),
    ("TRANSACTIONID_UNMATCHED", lib.ERR_LIB_CMP, 152),
    ("TRANSFER_ERROR", lib.ERR_LIB_CMP, 159),
    ("UNEXPECTED_PKIBODY", lib.ERR_LIB_CMP, 133),
    ("UNEXPECTED_PKISTATUS", lib.ERR_LIB_CMP, 185),
    ("UNEXPECTED_PVNO", lib.ERR_LIB_CMP, 153),
    ("UNKNOWN_ALGORITHM_ID", lib.ERR_LIB_CMP, 134),
    ("UNKNOWN_CERT_TYPE", lib.ERR_LIB_CMP, 135),
    ("UNKNOWN_PKISTATUS", lib.ERR_LIB_CMP, 186),
    ("UNSUPPORTED_ALGORITHM", lib.ERR_LIB_CMP, 136),
    ("UNSUPPORTED_KEY_TYPE", lib.ERR_LIB_CMP, 137),
    ("UNSUPPORTED_PROTECTION_ALG_DHBASEDMAC", lib.ERR_LIB_CMP, 154),
    ("VALUE_TOO_LARGE", lib.ERR_LIB_CMP, 175),
    ("VALUE_TOO_SMALL", lib.ERR_LIB_CMP, 177),
    ("WRONG_ALGORITHM_OID", lib.ERR_LIB_CMP, 138),
    ("WRONG_CERTID", lib.ERR_LIB_CMP, 189),
    ("WRONG_CERTID_IN_RP", lib.ERR_LIB_CMP, 187),
    ("WRONG_PBM_VALUE", lib.ERR_LIB_CMP, 155),
    ("WRONG_RP_COMPONENT_COUNT", lib.ERR_LIB_CMP, 188),
    ("WRONG_SERIAL_IN_RP", lib.ERR_LIB_CMP, 173),
    ("ADD_SIGNER_ERROR", lib.ERR_LIB_CMS, 99),
    ("ATTRIBUTE_ERROR", lib.ERR_LIB_CMS, 161),
    ("CERTIFICATE_ALREADY_PRESENT", lib.ERR_LIB_CMS, 175),
    ("CERTIFICATE_HAS_NO_KEYID", lib.ERR_LIB_CMS, 160),
    ("CERTIFICATE_VERIFY_ERROR", lib.ERR_LIB_CMS, 100),
    ("CIPHER_AEAD_SET_TAG_ERROR", lib.ERR_LIB_CMS, 184),
    ("CIPHER_GET_TAG", lib.ERR_LIB_CMS, 185),
    ("CIPHER_INITIALISATION_ERROR", lib.ERR_LIB_CMS, 101),
    ("CIPHER_PARAMETER_INITIALISATION_ERROR", lib.ERR_LIB_CMS, 102),
    ("CMS_DATAFINAL_ERROR", lib.ERR_LIB_CMS, 103),
    ("CMS_LIB", lib.ERR_LIB_CMS, 104),
    ("CONTENTIDENTIFIER_MISMATCH", lib.ERR_LIB_CMS, 170),
    ("CONTENT_NOT_FOUND", lib.ERR_LIB_CMS, 105),
    ("CONTENT_TYPE_MISMATCH", lib.ERR_LIB_CMS, 171),
    ("CONTENT_TYPE_NOT_COMPRESSED_DATA", lib.ERR_LIB_CMS, 106),
    ("CONTENT_TYPE_NOT_ENVELOPED_DATA", lib.ERR_LIB_CMS, 107),
    ("CONTENT_TYPE_NOT_SIGNED_DATA", lib.ERR_LIB_CMS, 108),
    ("CONTENT_VERIFY_ERROR", lib.ERR_LIB_CMS, 109),
    ("CTRL_ERROR", lib.ERR_LIB_CMS, 110),
    ("CTRL_FAILURE", lib.ERR_LIB_CMS, 111),
    ("DECODE_ERROR", lib.ERR_LIB_CMS, 187),
    ("DECRYPT_ERROR", lib.ERR_LIB_CMS, 112),
    ("ERROR_GETTING_PUBLIC_KEY", lib.ERR_LIB_CMS, 113),
    ("ERROR_READING_MESSAGEDIGEST_ATTRIBUTE", lib.ERR_LIB_CMS, 114),
    ("ERROR_SETTING_KEY", lib.ERR_LIB_CMS, 115),
    ("ERROR_SETTING_RECIPIENTINFO", lib.ERR_LIB_CMS, 116),
    ("ESS_SIGNING_CERTID_MISMATCH_ERROR", lib.ERR_LIB_CMS, 183),
    ("INVALID_ENCRYPTED_KEY_LENGTH", lib.ERR_LIB_CMS, 117),
    ("INVALID_KEY_ENCRYPTION_PARAMETER", lib.ERR_LIB_CMS, 176),
    ("INVALID_KEY_LENGTH", lib.ERR_LIB_CMS, 118),
    ("INVALID_LABEL", lib.ERR_LIB_CMS, 190),
    ("INVALID_OAEP_PARAMETERS", lib.ERR_LIB_CMS, 191),
    ("KDF_PARAMETER_ERROR", lib.ERR_LIB_CMS, 186),
    ("MD_BIO_INIT_ERROR", lib.ERR_LIB_CMS, 119),
    ("MESSAGEDIGEST_ATTRIBUTE_WRONG_LENGTH", lib.ERR_LIB_CMS, 120),
    ("MESSAGEDIGEST_WRONG_LENGTH", lib.ERR_LIB_CMS, 121),
    ("MSGSIGDIGEST_ERROR", lib.ERR_LIB_CMS, 172),
    ("MSGSIGDIGEST_VERIFICATION_FAILURE", lib.ERR_LIB_CMS, 162),
    ("MSGSIGDIGEST_WRONG_LENGTH", lib.ERR_LIB_CMS, 163),
    ("NEED_ONE_SIGNER", lib.ERR_LIB_CMS, 164),
    ("NOT_A_SIGNED_RECEIPT", lib.ERR_LIB_CMS, 165),
    ("NOT_ENCRYPTED_DATA", lib.ERR_LIB_CMS, 122),
    ("NOT_KEK", lib.ERR_LIB_CMS, 123),
    ("NOT_KEY_AGREEMENT", lib.ERR_LIB_CMS, 181),
    ("NOT_KEY_TRANSPORT", lib.ERR_LIB_CMS, 124),
    ("NOT_PWRI", lib.ERR_LIB_CMS, 177),
    ("NOT_SUPPORTED_FOR_THIS_KEY_TYPE", lib.ERR_LIB_CMS, 125),
    ("NO_CIPHER", lib.ERR_LIB_CMS, 126),
    ("NO_CONTENT", lib.ERR_LIB_CMS, 127),
    ("NO_CONTENT_TYPE", lib.ERR_LIB_CMS, 173),
    ("NO_DEFAULT_DIGEST", lib.ERR_LIB_CMS, 128),
    ("NO_DIGEST_SET", lib.ERR_LIB_CMS, 129),
    ("NO_KEY", lib.ERR_LIB_CMS, 130),
    ("NO_KEY_OR_CERT", lib.ERR_LIB_CMS, 174),
    ("NO_MATCHING_DIGEST", lib.ERR_LIB_CMS, 131),
    ("NO_MATCHING_RECIPIENT", lib.ERR_LIB_CMS, 132),
    ("NO_MATCHING_SIGNATURE", lib.ERR_LIB_CMS, 166),
    ("NO_MSGSIGDIGEST", lib.ERR_LIB_CMS, 167),
    ("NO_PASSWORD", lib.ERR_LIB_CMS, 178),
    ("NO_PRIVATE_KEY", lib.ERR_LIB_CMS, 133),
    ("NO_PUBLIC_KEY", lib.ERR_LIB_CMS, 134),
    ("NO_RECEIPT_REQUEST", lib.ERR_LIB_CMS, 168),
    ("NO_SIGNERS", lib.ERR_LIB_CMS, 135),
    ("PEER_KEY_ERROR", lib.ERR_LIB_CMS, 188),
    ("PRIVATE_KEY_DOES_NOT_MATCH_CERTIFICATE", lib.ERR_LIB_CMS, 136),
    ("RECEIPT_DECODE_ERROR", lib.ERR_LIB_CMS, 169),
    ("RECIPIENT_ERROR", lib.ERR_LIB_CMS, 137),
    ("SHARED_INFO_ERROR", lib.ERR_LIB_CMS, 189),
    ("SIGNER_CERTIFICATE_NOT_FOUND", lib.ERR_LIB_CMS, 138),
    ("SIGNFINAL_ERROR", lib.ERR_LIB_CMS, 139),
    ("SMIME_TEXT_ERROR", lib.ERR_LIB_CMS, 140),
    ("STORE_INIT_ERROR", lib.ERR_LIB_CMS, 141),
    ("TYPE_NOT_COMPRESSED_DATA", lib.ERR_LIB_CMS, 142),
    ("TYPE_NOT_DATA", lib.ERR_LIB_CMS, 143),
    ("TYPE_NOT_DIGESTED_DATA", lib.ERR_LIB_CMS, 144),
    ("TYPE_NOT_ENCRYPTED_DATA", lib.ERR_LIB_CMS, 145),
    ("TYPE_NOT_ENVELOPED_DATA", lib.ERR_LIB_CMS, 146),
    ("UNABLE_TO_FINALIZE_CONTEXT", lib.ERR_LIB_CMS, 147),
    ("UNKNOWN_CIPHER", lib.ERR_LIB_CMS, 148),
    ("UNKNOWN_DIGEST_ALGORITHM", lib.ERR_LIB_CMS, 149),
    ("UNKNOWN_ID", lib.ERR_LIB_CMS, 150),
    ("UNSUPPORTED_COMPRESSION_ALGORITHM", lib.ERR_LIB_CMS, 151),
    ("UNSUPPORTED_CONTENT_TYPE", lib.ERR_LIB_CMS, 152),
    ("UNSUPPORTED_ENCRYPTION_TYPE", lib.ERR_LIB_CMS, 192),
    ("UNSUPPORTED_KEK_ALGORITHM", lib.ERR_LIB_CMS, 153),
    ("UNSUPPORTED_KEY_ENCRYPTION_ALGORITHM", lib.ERR_LIB_CMS, 179),
    ("UNSUPPORTED_LABEL_SOURCE", lib.ERR_LIB_CMS, 193),
    ("UNSUPPORTED_RECIPIENTINFO_TYPE", lib.ERR_LIB_CMS, 155),
    ("UNSUPPORTED_RECIPIENT_TYPE", lib.ERR_LIB_CMS, 154),
    ("UNSUPPORTED_TYPE", lib.ERR_LIB_CMS, 156),
    ("UNWRAP_ERROR", lib.ERR_LIB_CMS, 157),
    ("UNWRAP_FAILURE", lib.ERR_LIB_CMS, 180),
    ("VERIFICATION_FAILURE", lib.ERR_LIB_CMS, 158),
    ("WRAP_ERROR", lib.ERR_LIB_CMS, 159),
    ("ZLIB_DEFLATE_ERROR", lib.ERR_LIB_COMP, 99),
    ("ZLIB_INFLATE_ERROR", lib.ERR_LIB_COMP, 100),
    ("ZLIB_NOT_SUPPORTED", lib.ERR_LIB_COMP, 101),
    ("ERROR_LOADING_DSO", lib.ERR_LIB_CONF, 110),
    ("INVALID_PRAGMA", lib.ERR_LIB_CONF, 122),
    ("LIST_CANNOT_BE_NULL", lib.ERR_LIB_CONF, 115),
    ("MANDATORY_BRACES_IN_VARIABLE_EXPANSION", lib.ERR_LIB_CONF, 123),
    ("MISSING_CLOSE_SQUARE_BRACKET", lib.ERR_LIB_CONF, 100),
    ("MISSING_EQUAL_SIGN", lib.ERR_LIB_CONF, 101),
    ("MISSING_INIT_FUNCTION", lib.ERR_LIB_CONF, 112),
    ("MODULE_INITIALIZATION_ERROR", lib.ERR_LIB_CONF, 109),
    ("NO_CLOSE_BRACE", lib.ERR_LIB_CONF, 102),
    ("NO_CONF", lib.ERR_LIB_CONF, 105),
    ("NO_CONF_OR_ENVIRONMENT_VARIABLE", lib.ERR_LIB_CONF, 106),
    ("NO_SECTION", lib.ERR_LIB_CONF, 107),
    ("NO_SUCH_FILE", lib.ERR_LIB_CONF, 114),
    ("NO_VALUE", lib.ERR_LIB_CONF, 108),
    ("NUMBER_TOO_LARGE", lib.ERR_LIB_CONF, 121),
    ("OPENSSL_CONF_REFERENCES_MISSING_SECTION", lib.ERR_LIB_CONF, 124),
    ("RECURSIVE_DIRECTORY_INCLUDE", lib.ERR_LIB_CONF, 111),
    ("RELATIVE_PATH", lib.ERR_LIB_CONF, 125),
    ("SSL_COMMAND_SECTION_EMPTY", lib.ERR_LIB_CONF, 117),
    ("SSL_COMMAND_SECTION_NOT_FOUND", lib.ERR_LIB_CONF, 118),
    ("SSL_SECTION_EMPTY", lib.ERR_LIB_CONF, 119),
    ("SSL_SECTION_NOT_FOUND", lib.ERR_LIB_CONF, 120),
    ("UNABLE_TO_CREATE_NEW_SECTION", lib.ERR_LIB_CONF, 103),
    ("UNKNOWN_MODULE_NAME", lib.ERR_LIB_CONF, 113),
    ("VARIABLE_EXPANSION_TOO_LONG", lib.ERR_LIB_CONF, 116),
    ("VARIABLE_HAS_NO_VALUE", lib.ERR_LIB_CONF, 104),
    ("BAD_PBM_ITERATIONCOUNT", lib.ERR_LIB_CRMF, 100),
    ("CRMFERROR", lib.ERR_LIB_CRMF, 102),
    ("ERROR", lib.ERR_LIB_CRMF, 103),
    ("ERROR_DECODING_CERTIFICATE", lib.ERR_LIB_CRMF, 104),
    ("ERROR_DECRYPTING_CERTIFICATE", lib.ERR_LIB_CRMF, 105),
    ("ERROR_DECRYPTING_SYMMETRIC_KEY", lib.ERR_LIB_CRMF, 106),
    ("FAILURE_OBTAINING_RANDOM", lib.ERR_LIB_CRMF, 107),
    ("ITERATIONCOUNT_BELOW_100", lib.ERR_LIB_CRMF, 108),
    ("MALFORMED_IV", lib.ERR_LIB_CRMF, 101),
    ("NULL_ARGUMENT", lib.ERR_LIB_CRMF, 109),
    ("POPOSKINPUT_NOT_SUPPORTED", lib.ERR_LIB_CRMF, 113),
    ("POPO_INCONSISTENT_PUBLIC_KEY", lib.ERR_LIB_CRMF, 117),
    ("POPO_MISSING", lib.ERR_LIB_CRMF, 121),
    ("POPO_MISSING_PUBLIC_KEY", lib.ERR_LIB_CRMF, 118),
    ("POPO_MISSING_SUBJECT", lib.ERR_LIB_CRMF, 119),
    ("POPO_RAVERIFIED_NOT_ACCEPTED", lib.ERR_LIB_CRMF, 120),
    ("SETTING_MAC_ALGOR_FAILURE", lib.ERR_LIB_CRMF, 110),
    ("SETTING_OWF_ALGOR_FAILURE", lib.ERR_LIB_CRMF, 111),
    ("UNSUPPORTED_ALGORITHM", lib.ERR_LIB_CRMF, 112),
    ("UNSUPPORTED_CIPHER", lib.ERR_LIB_CRMF, 114),
    ("UNSUPPORTED_METHOD_FOR_CREATING_POPO", lib.ERR_LIB_CRMF, 115),
    ("UNSUPPORTED_POPO_METHOD", lib.ERR_LIB_CRMF, 116),
    ("BAD_ALGORITHM_NAME", lib.ERR_LIB_CRYPTO, 117),
    ("CONFLICTING_NAMES", lib.ERR_LIB_CRYPTO, 118),
    ("HEX_STRING_TOO_SHORT", lib.ERR_LIB_CRYPTO, 121),
    ("ILLEGAL_HEX_DIGIT", lib.ERR_LIB_CRYPTO, 102),
    ("INSUFFICIENT_DATA_SPACE", lib.ERR_LIB_CRYPTO, 106),
    ("INSUFFICIENT_PARAM_SIZE", lib.ERR_LIB_CRYPTO, 107),
    ("INSUFFICIENT_SECURE_DATA_SPACE", lib.ERR_LIB_CRYPTO, 108),
    ("INVALID_NULL_ARGUMENT", lib.ERR_LIB_CRYPTO, 109),
    ("INVALID_OSSL_PARAM_TYPE", lib.ERR_LIB_CRYPTO, 110),
    ("ODD_NUMBER_OF_DIGITS", lib.ERR_LIB_CRYPTO, 103),
    ("PROVIDER_ALREADY_EXISTS", lib.ERR_LIB_CRYPTO, 104),
    ("PROVIDER_SECTION_ERROR", lib.ERR_LIB_CRYPTO, 105),
    ("RANDOM_SECTION_ERROR", lib.ERR_LIB_CRYPTO, 119),
    ("SECURE_MALLOC_FAILURE", lib.ERR_LIB_CRYPTO, 111),
    ("STRING_TOO_LONG", lib.ERR_LIB_CRYPTO, 112),
    ("TOO_MANY_BYTES", lib.ERR_LIB_CRYPTO, 113),
    ("TOO_MANY_RECORDS", lib.ERR_LIB_CRYPTO, 114),
    ("TOO_SMALL_BUFFER", lib.ERR_LIB_CRYPTO, 116),
    ("UNKNOWN_NAME_IN_RANDOM_SECTION", lib.ERR_LIB_CRYPTO, 120),
    ("ZERO_LENGTH_NUMBER", lib.ERR_LIB_CRYPTO, 115),
    ("BASE64_DECODE_ERROR", lib.ERR_LIB_CT, 108),
    ("INVALID_LOG_ID_LENGTH", lib.ERR_LIB_CT, 100),
    ("LOG_CONF_INVALID", lib.ERR_LIB_CT, 109),
    ("LOG_CONF_INVALID_KEY", lib.ERR_LIB_CT, 110),
    ("LOG_CONF_MISSING_DESCRIPTION", lib.ERR_LIB_CT, 111),
    ("LOG_CONF_MISSING_KEY", lib.ERR_LIB_CT, 112),
    ("LOG_KEY_INVALID", lib.ERR_LIB_CT, 113),
    ("SCT_FUTURE_TIMESTAMP", lib.ERR_LIB_CT, 116),
    ("SCT_INVALID", lib.ERR_LIB_CT, 104),
    ("SCT_INVALID_SIGNATURE", lib.ERR_LIB_CT, 107),
    ("SCT_LIST_INVALID", lib.ERR_LIB_CT, 105),
    ("SCT_LOG_ID_MISMATCH", lib.ERR_LIB_CT, 114),
    ("SCT_NOT_SET", lib.ERR_LIB_CT, 106),
    ("SCT_UNSUPPORTED_VERSION", lib.ERR_LIB_CT, 115),
    ("UNRECOGNIZED_SIGNATURE_NID", lib.ERR_LIB_CT, 101),
    ("UNSUPPORTED_ENTRY_TYPE", lib.ERR_LIB_CT, 102),
    ("UNSUPPORTED_VERSION", lib.ERR_LIB_CT, 103),
    ("BAD_FFC_PARAMETERS", lib.ERR_LIB_DH, 127),
    ("BAD_GENERATOR", lib.ERR_LIB_DH, 101),
    ("BN_DECODE_ERROR", lib.ERR_LIB_DH, 109),
    ("BN_ERROR", lib.ERR_LIB_DH, 106),
    ("CHECK_INVALID_J_VALUE", lib.ERR_LIB_DH, 115),
    ("CHECK_INVALID_Q_VALUE", lib.ERR_LIB_DH, 116),
    ("CHECK_PUBKEY_INVALID", lib.ERR_LIB_DH, 122),
    ("CHECK_PUBKEY_TOO_LARGE", lib.ERR_LIB_DH, 123),
    ("CHECK_PUBKEY_TOO_SMALL", lib.ERR_LIB_DH, 124),
    ("CHECK_P_NOT_PRIME", lib.ERR_LIB_DH, 117),
    ("CHECK_P_NOT_SAFE_PRIME", lib.ERR_LIB_DH, 118),
    ("CHECK_Q_NOT_PRIME", lib.ERR_LIB_DH, 119),
    ("DECODE_ERROR", lib.ERR_LIB_DH, 104),
    ("INVALID_PARAMETER_NAME", lib.ERR_LIB_DH, 110),
    ("INVALID_PARAMETER_NID", lib.ERR_LIB_DH, 114),
    ("INVALID_PUBKEY", lib.ERR_LIB_DH, 102),
    ("INVALID_SECRET", lib.ERR_LIB_DH, 128),
    ("KDF_PARAMETER_ERROR", lib.ERR_LIB_DH, 112),
    ("KEYS_NOT_SET", lib.ERR_LIB_DH, 108),
    ("MISSING_PUBKEY", lib.ERR_LIB_DH, 125),
    ("MODULUS_TOO_LARGE", lib.ERR_LIB_DH, 103),
    ("MODULUS_TOO_SMALL", lib.ERR_LIB_DH, 126),
    ("NOT_SUITABLE_GENERATOR", lib.ERR_LIB_DH, 120),
    ("NO_PARAMETERS_SET", lib.ERR_LIB_DH, 107),
    ("NO_PRIVATE_VALUE", lib.ERR_LIB_DH, 100),
    ("PARAMETER_ENCODING_ERROR", lib.ERR_LIB_DH, 105),
    ("PEER_KEY_ERROR", lib.ERR_LIB_DH, 111),
    ("SHARED_INFO_ERROR", lib.ERR_LIB_DH, 113),
    ("UNABLE_TO_CHECK_GENERATOR", lib.ERR_LIB_DH, 121),
    ("BAD_FFC_PARAMETERS", lib.ERR_LIB_DSA, 114),
    ("BAD_Q_VALUE", lib.ERR_LIB_DSA, 102),
    ("BN_DECODE_ERROR", lib.ERR_LIB_DSA, 108),
    ("BN_ERROR", lib.ERR_LIB_DSA, 109),
    ("DECODE_ERROR", lib.ERR_LIB_DSA, 104),
    ("INVALID_DIGEST_TYPE", lib.ERR_LIB_DSA, 106),
    ("INVALID_PARAMETERS", lib.ERR_LIB_DSA, 112),
    ("MISSING_PARAMETERS", lib.ERR_LIB_DSA, 101),
    ("MISSING_PRIVATE_KEY", lib.ERR_LIB_DSA, 111),
    ("MODULUS_TOO_LARGE", lib.ERR_LIB_DSA, 103),
    ("NO_PARAMETERS_SET", lib.ERR_LIB_DSA, 107),
    ("PARAMETER_ENCODING_ERROR", lib.ERR_LIB_DSA, 105),
    ("P_NOT_PRIME", lib.ERR_LIB_DSA, 115),
    ("Q_NOT_PRIME", lib.ERR_LIB_DSA, 113),
    ("SEED_LEN_SMALL", lib.ERR_LIB_DSA, 110),
    ("CTRL_FAILED", lib.ERR_LIB_DSO, 100),
    ("DSO_ALREADY_LOADED", lib.ERR_LIB_DSO, 110),
    ("EMPTY_FILE_STRUCTURE", lib.ERR_LIB_DSO, 113),
    ("FAILURE", lib.ERR_LIB_DSO, 114),
    ("FILENAME_TOO_BIG", lib.ERR_LIB_DSO, 101),
    ("FINISH_FAILED", lib.ERR_LIB_DSO, 102),
    ("INCORRECT_FILE_SYNTAX", lib.ERR_LIB_DSO, 115),
    ("LOAD_FAILED", lib.ERR_LIB_DSO, 103),
    ("NAME_TRANSLATION_FAILED", lib.ERR_LIB_DSO, 109),
    ("NO_FILENAME", lib.ERR_LIB_DSO, 111),
    ("NULL_HANDLE", lib.ERR_LIB_DSO, 104),
    ("SET_FILENAME_FAILED", lib.ERR_LIB_DSO, 112),
    ("STACK_ERROR", lib.ERR_LIB_DSO, 105),
    ("SYM_FAILURE", lib.ERR_LIB_DSO, 106),
    ("UNLOAD_FAILED", lib.ERR_LIB_DSO, 107),
    ("UNSUPPORTED", lib.ERR_LIB_DSO, 108),
    ("ASN1_ERROR", lib.ERR_LIB_EC, 115),
    ("BAD_SIGNATURE", lib.ERR_LIB_EC, 156),
    ("BIGNUM_OUT_OF_RANGE", lib.ERR_LIB_EC, 144),
    ("BUFFER_TOO_SMALL", lib.ERR_LIB_EC, 100),
    ("CANNOT_INVERT", lib.ERR_LIB_EC, 165),
    ("COORDINATES_OUT_OF_RANGE", lib.ERR_LIB_EC, 146),
    ("CURVE_DOES_NOT_SUPPORT_ECDH", lib.ERR_LIB_EC, 160),
    ("CURVE_DOES_NOT_SUPPORT_ECDSA", lib.ERR_LIB_EC, 170),
    ("CURVE_DOES_NOT_SUPPORT_SIGNING", lib.ERR_LIB_EC, 159),
    ("DECODE_ERROR", lib.ERR_LIB_EC, 142),
    ("DISCRIMINANT_IS_ZERO", lib.ERR_LIB_EC, 118),
    ("EC_GROUP_NEW_BY_NAME_FAILURE", lib.ERR_LIB_EC, 119),
    ("FAILED_MAKING_PUBLIC_KEY", lib.ERR_LIB_EC, 166),
    ("FIELD_TOO_LARGE", lib.ERR_LIB_EC, 143),
    ("GF2M_NOT_SUPPORTED", lib.ERR_LIB_EC, 147),
    ("GROUP2PKPARAMETERS_FAILURE", lib.ERR_LIB_EC, 120),
    ("I2D_ECPKPARAMETERS_FAILURE", lib.ERR_LIB_EC, 121),
    ("INCOMPATIBLE_OBJECTS", lib.ERR_LIB_EC, 101),
    ("INVALID_A", lib.ERR_LIB_EC, 168),
    ("INVALID_ARGUMENT", lib.ERR_LIB_EC, 112),
    ("INVALID_B", lib.ERR_LIB_EC, 169),
    ("INVALID_COFACTOR", lib.ERR_LIB_EC, 171),
    ("INVALID_COMPRESSED_POINT", lib.ERR_LIB_EC, 110),
    ("INVALID_COMPRESSION_BIT", lib.ERR_LIB_EC, 109),
    ("INVALID_CURVE", lib.ERR_LIB_EC, 141),
    ("INVALID_DIGEST", lib.ERR_LIB_EC, 151),
    ("INVALID_DIGEST_TYPE", lib.ERR_LIB_EC, 138),
    ("INVALID_ENCODING", lib.ERR_LIB_EC, 102),
    ("INVALID_FIELD", lib.ERR_LIB_EC, 103),
    ("INVALID_FORM", lib.ERR_LIB_EC, 104),
    ("INVALID_GENERATOR", lib.ERR_LIB_EC, 173),
    ("INVALID_GROUP_ORDER", lib.ERR_LIB_EC, 122),
    ("INVALID_KEY", lib.ERR_LIB_EC, 116),
    ("INVALID_LENGTH", lib.ERR_LIB_EC, 117),
    ("INVALID_NAMED_GROUP_CONVERSION", lib.ERR_LIB_EC, 174),
    ("INVALID_OUTPUT_LENGTH", lib.ERR_LIB_EC, 161),
    ("INVALID_P", lib.ERR_LIB_EC, 172),
    ("INVALID_PEER_KEY", lib.ERR_LIB_EC, 133),
    ("INVALID_PENTANOMIAL_BASIS", lib.ERR_LIB_EC, 132),
    ("INVALID_PRIVATE_KEY", lib.ERR_LIB_EC, 123),
    ("INVALID_SEED", lib.ERR_LIB_EC, 175),
    ("INVALID_TRINOMIAL_BASIS", lib.ERR_LIB_EC, 137),
    ("KDF_PARAMETER_ERROR", lib.ERR_LIB_EC, 148),
    ("KEYS_NOT_SET", lib.ERR_LIB_EC, 140),
    ("LADDER_POST_FAILURE", lib.ERR_LIB_EC, 136),
    ("LADDER_PRE_FAILURE", lib.ERR_LIB_EC, 153),
    ("LADDER_STEP_FAILURE", lib.ERR_LIB_EC, 162),
    ("MISSING_OID", lib.ERR_LIB_EC, 167),
    ("MISSING_PARAMETERS", lib.ERR_LIB_EC, 124),
    ("MISSING_PRIVATE_KEY", lib.ERR_LIB_EC, 125),
    ("NEED_NEW_SETUP_VALUES", lib.ERR_LIB_EC, 157),
    ("NOT_A_NIST_PRIME", lib.ERR_LIB_EC, 135),
    ("NOT_IMPLEMENTED", lib.ERR_LIB_EC, 126),
    ("NOT_INITIALIZED", lib.ERR_LIB_EC, 111),
    ("NO_PARAMETERS_SET", lib.ERR_LIB_EC, 139),
    ("NO_PRIVATE_VALUE", lib.ERR_LIB_EC, 154),
    ("OPERATION_NOT_SUPPORTED", lib.ERR_LIB_EC, 152),
    ("PASSED_NULL_PARAMETER", lib.ERR_LIB_EC, 134),
    ("PEER_KEY_ERROR", lib.ERR_LIB_EC, 149),
    ("POINT_ARITHMETIC_FAILURE", lib.ERR_LIB_EC, 155),
    ("POINT_AT_INFINITY", lib.ERR_LIB_EC, 106),
    ("POINT_COORDINATES_BLIND_FAILURE", lib.ERR_LIB_EC, 163),
    ("POINT_IS_NOT_ON_CURVE", lib.ERR_LIB_EC, 107),
    ("RANDOM_NUMBER_GENERATION_FAILED", lib.ERR_LIB_EC, 158),
    ("SHARED_INFO_ERROR", lib.ERR_LIB_EC, 150),
    ("SLOT_FULL", lib.ERR_LIB_EC, 108),
    ("UNDEFINED_GENERATOR", lib.ERR_LIB_EC, 113),
    ("UNDEFINED_ORDER", lib.ERR_LIB_EC, 128),
    ("UNKNOWN_COFACTOR", lib.ERR_LIB_EC, 164),
    ("UNKNOWN_GROUP", lib.ERR_LIB_EC, 129),
    ("UNKNOWN_ORDER", lib.ERR_LIB_EC, 114),
    ("UNSUPPORTED_FIELD", lib.ERR_LIB_EC, 131),
    ("WRONG_CURVE_PARAMETERS", lib.ERR_LIB_EC, 145),
    ("WRONG_ORDER", lib.ERR_LIB_EC, 130),
    ("ALREADY_LOADED", lib.ERR_LIB_ENGINE, 100),
    ("ARGUMENT_IS_NOT_A_NUMBER", lib.ERR_LIB_ENGINE, 133),
    ("CMD_NOT_EXECUTABLE", lib.ERR_LIB_ENGINE, 134),
    ("COMMAND_TAKES_INPUT", lib.ERR_LIB_ENGINE, 135),
    ("COMMAND_TAKES_NO_INPUT", lib.ERR_LIB_ENGINE, 136),
    ("CONFLICTING_ENGINE_ID", lib.ERR_LIB_ENGINE, 103),
    ("CTRL_COMMAND_NOT_IMPLEMENTED", lib.ERR_LIB_ENGINE, 119),
    ("DSO_FAILURE", lib.ERR_LIB_ENGINE, 104),
    ("DSO_NOT_FOUND", lib.ERR_LIB_ENGINE, 132),
    ("ENGINES_SECTION_ERROR", lib.ERR_LIB_ENGINE, 148),
    ("ENGINE_CONFIGURATION_ERROR", lib.ERR_LIB_ENGINE, 102),
    ("ENGINE_IS_NOT_IN_LIST", lib.ERR_LIB_ENGINE, 105),
    ("ENGINE_SECTION_ERROR", lib.ERR_LIB_ENGINE, 149),
    ("FAILED_LOADING_PRIVATE_KEY", lib.ERR_LIB_ENGINE, 128),
    ("FAILED_LOADING_PUBLIC_KEY", lib.ERR_LIB_ENGINE, 129),
    ("FINISH_FAILED", lib.ERR_LIB_ENGINE, 106),
    ("ID_OR_NAME_MISSING", lib.ERR_LIB_ENGINE, 108),
    ("INIT_FAILED", lib.ERR_LIB_ENGINE, 109),
    ("INTERNAL_LIST_ERROR", lib.ERR_LIB_ENGINE, 110),
    ("INVALID_ARGUMENT", lib.ERR_LIB_ENGINE, 143),
    ("INVALID_CMD_NAME", lib.ERR_LIB_ENGINE, 137),
    ("INVALID_CMD_NUMBER", lib.ERR_LIB_ENGINE, 138),
    ("INVALID_INIT_VALUE", lib.ERR_LIB_ENGINE, 151),
    ("INVALID_STRING", lib.ERR_LIB_ENGINE, 150),
    ("NOT_INITIALISED", lib.ERR_LIB_ENGINE, 117),
    ("NOT_LOADED", lib.ERR_LIB_ENGINE, 112),
    ("NO_CONTROL_FUNCTION", lib.ERR_LIB_ENGINE, 120),
    ("NO_INDEX", lib.ERR_LIB_ENGINE, 144),
    ("NO_LOAD_FUNCTION", lib.ERR_LIB_ENGINE, 125),
    ("NO_REFERENCE", lib.ERR_LIB_ENGINE, 130),
    ("NO_SUCH_ENGINE", lib.ERR_LIB_ENGINE, 116),
    ("UNIMPLEMENTED_CIPHER", lib.ERR_LIB_ENGINE, 146),
    ("UNIMPLEMENTED_DIGEST", lib.ERR_LIB_ENGINE, 147),
    ("UNIMPLEMENTED_PUBLIC_KEY_METHOD", lib.ERR_LIB_ENGINE, 101),
    ("VERSION_INCOMPATIBILITY", lib.ERR_LIB_ENGINE, 145),
    ("EMPTY_ESS_CERT_ID_LIST", lib.ERR_LIB_ESS, 107),
    ("ESS_CERT_DIGEST_ERROR", lib.ERR_LIB_ESS, 103),
    ("ESS_CERT_ID_NOT_FOUND", lib.ERR_LIB_ESS, 104),
    ("ESS_CERT_ID_WRONG_ORDER", lib.ERR_LIB_ESS, 105),
    ("ESS_DIGEST_ALG_UNKNOWN", lib.ERR_LIB_ESS, 106),
    ("ESS_SIGNING_CERTIFICATE_ERROR", lib.ERR_LIB_ESS, 102),
    ("ESS_SIGNING_CERT_ADD_ERROR", lib.ERR_LIB_ESS, 100),
    ("ESS_SIGNING_CERT_V2_ADD_ERROR", lib.ERR_LIB_ESS, 101),
    ("MISSING_SIGNING_CERTIFICATE_ATTRIBUTE", lib.ERR_LIB_ESS, 108),
    ("AES_KEY_SETUP_FAILED", lib.ERR_LIB_EVP, 143),
    ("ARIA_KEY_SETUP_FAILED", lib.ERR_LIB_EVP, 176),
    ("BAD_ALGORITHM_NAME", lib.ERR_LIB_EVP, 200),
    ("BAD_DECRYPT", lib.ERR_LIB_EVP, 100),
    ("BAD_KEY_LENGTH", lib.ERR_LIB_EVP, 195),
    ("BUFFER_TOO_SMALL", lib.ERR_LIB_EVP, 155),
    ("CACHE_CONSTANTS_FAILED", lib.ERR_LIB_EVP, 225),
    ("CAMELLIA_KEY_SETUP_FAILED", lib.ERR_LIB_EVP, 157),
    ("CANNOT_GET_PARAMETERS", lib.ERR_LIB_EVP, 197),
    ("CANNOT_SET_PARAMETERS", lib.ERR_LIB_EVP, 198),
    ("CIPHER_NOT_GCM_MODE", lib.ERR_LIB_EVP, 184),
    ("CIPHER_PARAMETER_ERROR", lib.ERR_LIB_EVP, 122),
    ("COMMAND_NOT_SUPPORTED", lib.ERR_LIB_EVP, 147),
    ("CONFLICTING_ALGORITHM_NAME", lib.ERR_LIB_EVP, 201),
    ("COPY_ERROR", lib.ERR_LIB_EVP, 173),
    ("CTRL_NOT_IMPLEMENTED", lib.ERR_LIB_EVP, 132),
    ("CTRL_OPERATION_NOT_IMPLEMENTED", lib.ERR_LIB_EVP, 133),
    ("DATA_NOT_MULTIPLE_OF_BLOCK_LENGTH", lib.ERR_LIB_EVP, 138),
    ("DECODE_ERROR", lib.ERR_LIB_EVP, 114),
    ("DEFAULT_QUERY_PARSE_ERROR", lib.ERR_LIB_EVP, 210),
    ("DIFFERENT_KEY_TYPES", lib.ERR_LIB_EVP, 101),
    ("DIFFERENT_PARAMETERS", lib.ERR_LIB_EVP, 153),
    ("ERROR_LOADING_SECTION", lib.ERR_LIB_EVP, 165),
    ("EXPECTING_AN_HMAC_KEY", lib.ERR_LIB_EVP, 174),
    ("EXPECTING_AN_RSA_KEY", lib.ERR_LIB_EVP, 127),
    ("EXPECTING_A_DH_KEY", lib.ERR_LIB_EVP, 128),
    ("EXPECTING_A_DSA_KEY", lib.ERR_LIB_EVP, 129),
    ("EXPECTING_A_ECX_KEY", lib.ERR_LIB_EVP, 219),
    ("EXPECTING_A_EC_KEY", lib.ERR_LIB_EVP, 142),
    ("EXPECTING_A_POLY1305_KEY", lib.ERR_LIB_EVP, 164),
    ("EXPECTING_A_SIPHASH_KEY", lib.ERR_LIB_EVP, 175),
    ("FINAL_ERROR", lib.ERR_LIB_EVP, 188),
    ("GENERATE_ERROR", lib.ERR_LIB_EVP, 214),
    ("GET_RAW_KEY_FAILED", lib.ERR_LIB_EVP, 182),
    ("ILLEGAL_SCRYPT_PARAMETERS", lib.ERR_LIB_EVP, 171),
    ("INACCESSIBLE_DOMAIN_PARAMETERS", lib.ERR_LIB_EVP, 204),
    ("INACCESSIBLE_KEY", lib.ERR_LIB_EVP, 203),
    ("INITIALIZATION_ERROR", lib.ERR_LIB_EVP, 134),
    ("INPUT_NOT_INITIALIZED", lib.ERR_LIB_EVP, 111),
    ("INVALID_CUSTOM_LENGTH", lib.ERR_LIB_EVP, 185),
    ("INVALID_DIGEST", lib.ERR_LIB_EVP, 152),
    ("INVALID_IV_LENGTH", lib.ERR_LIB_EVP, 194),
    ("INVALID_KEY", lib.ERR_LIB_EVP, 163),
    ("INVALID_KEY_LENGTH", lib.ERR_LIB_EVP, 130),
    ("INVALID_LENGTH", lib.ERR_LIB_EVP, 221),
    ("INVALID_NULL_ALGORITHM", lib.ERR_LIB_EVP, 218),
    ("INVALID_OPERATION", lib.ERR_LIB_EVP, 148),
    ("INVALID_PROVIDER_FUNCTIONS", lib.ERR_LIB_EVP, 193),
    ("INVALID_SALT_LENGTH", lib.ERR_LIB_EVP, 186),
    ("INVALID_SECRET_LENGTH", lib.ERR_LIB_EVP, 223),
    ("INVALID_SEED_LENGTH", lib.ERR_LIB_EVP, 220),
    ("INVALID_VALUE", lib.ERR_LIB_EVP, 222),
    ("KEYMGMT_EXPORT_FAILURE", lib.ERR_LIB_EVP, 205),
    ("KEY_SETUP_FAILED", lib.ERR_LIB_EVP, 180),
    ("LOCKING_NOT_SUPPORTED", lib.ERR_LIB_EVP, 213),
    ("MEMORY_LIMIT_EXCEEDED", lib.ERR_LIB_EVP, 172),
    ("MESSAGE_DIGEST_IS_NULL", lib.ERR_LIB_EVP, 159),
    ("METHOD_NOT_SUPPORTED", lib.ERR_LIB_EVP, 144),
    ("MISSING_PARAMETERS", lib.ERR_LIB_EVP, 103),
    ("NOT_ABLE_TO_COPY_CTX", lib.ERR_LIB_EVP, 190),
    ("NOT_XOF_OR_INVALID_LENGTH", lib.ERR_LIB_EVP, 178),
    ("NO_CIPHER_SET", lib.ERR_LIB_EVP, 131),
    ("NO_DEFAULT_DIGEST", lib.ERR_LIB_EVP, 158),
    ("NO_DIGEST_SET", lib.ERR_LIB_EVP, 139),
    ("NO_IMPORT_FUNCTION", lib.ERR_LIB_EVP, 206),
    ("NO_KEYMGMT_AVAILABLE", lib.ERR_LIB_EVP, 199),
    ("NO_KEYMGMT_PRESENT", lib.ERR_LIB_EVP, 196),
    ("NO_KEY_SET", lib.ERR_LIB_EVP, 154),
    ("NO_OPERATION_SET", lib.ERR_LIB_EVP, 149),
    ("NULL_MAC_PKEY_CTX", lib.ERR_LIB_EVP, 208),
    ("ONLY_ONESHOT_SUPPORTED", lib.ERR_LIB_EVP, 177),
    ("OPERATION_NOT_INITIALIZED", lib.ERR_LIB_EVP, 151),
    ("OPERATION_NOT_SUPPORTED_FOR_THIS_KEYTYPE", lib.ERR_LIB_EVP, 150),
    ("OUTPUT_WOULD_OVERFLOW", lib.ERR_LIB_EVP, 202),
    ("PARAMETER_TOO_LARGE", lib.ERR_LIB_EVP, 187),
    ("PARTIALLY_OVERLAPPING", lib.ERR_LIB_EVP, 162),
    ("PBKDF2_ERROR", lib.ERR_LIB_EVP, 181),
    ("PKEY_APPLICATION_ASN1_METHOD_ALREADY_REGISTERED", lib.ERR_LIB_EVP, 179),
    ("PRIVATE_KEY_DECODE_ERROR", lib.ERR_LIB_EVP, 145),
    ("PRIVATE_KEY_ENCODE_ERROR", lib.ERR_LIB_EVP, 146),
    ("PUBLIC_KEY_NOT_RSA", lib.ERR_LIB_EVP, 106),
    ("SETTING_XOF_FAILED", lib.ERR_LIB_EVP, 227),
    ("SET_DEFAULT_PROPERTY_FAILURE", lib.ERR_LIB_EVP, 209),
    ("TOO_MANY_RECORDS", lib.ERR_LIB_EVP, 183),
    ("UNABLE_TO_ENABLE_LOCKING", lib.ERR_LIB_EVP, 212),
    ("UNABLE_TO_GET_MAXIMUM_REQUEST_SIZE", lib.ERR_LIB_EVP, 215),
    ("UNABLE_TO_GET_RANDOM_STRENGTH", lib.ERR_LIB_EVP, 216),
    ("UNABLE_TO_LOCK_CONTEXT", lib.ERR_LIB_EVP, 211),
    ("UNABLE_TO_SET_CALLBACKS", lib.ERR_LIB_EVP, 217),
    ("UNKNOWN_CIPHER", lib.ERR_LIB_EVP, 160),
    ("UNKNOWN_DIGEST", lib.ERR_LIB_EVP, 161),
    ("UNKNOWN_KEY_TYPE", lib.ERR_LIB_EVP, 207),
    ("UNKNOWN_OPTION", lib.ERR_LIB_EVP, 169),
    ("UNKNOWN_PBE_ALGORITHM", lib.ERR_LIB_EVP, 121),
    ("UNSUPPORTED_ALGORITHM", lib.ERR_LIB_EVP, 156),
    ("UNSUPPORTED_CIPHER", lib.ERR_LIB_EVP, 107),
    ("UNSUPPORTED_KEYLENGTH", lib.ERR_LIB_EVP, 123),
    ("UNSUPPORTED_KEY_DERIVATION_FUNCTION", lib.ERR_LIB_EVP, 124),
    ("UNSUPPORTED_KEY_SIZE", lib.ERR_LIB_EVP, 108),
    ("UNSUPPORTED_KEY_TYPE", lib.ERR_LIB_EVP, 224),
    ("UNSUPPORTED_NUMBER_OF_ROUNDS", lib.ERR_LIB_EVP, 135),
    ("UNSUPPORTED_PRF", lib.ERR_LIB_EVP, 125),
    ("UNSUPPORTED_PRIVATE_KEY_ALGORITHM", lib.ERR_LIB_EVP, 118),
    ("UNSUPPORTED_SALT_TYPE", lib.ERR_LIB_EVP, 126),
    ("UPDATE_ERROR", lib.ERR_LIB_EVP, 189),
    ("WRAP_MODE_NOT_ALLOWED", lib.ERR_LIB_EVP, 170),
    ("WRONG_FINAL_BLOCK_LENGTH", lib.ERR_LIB_EVP, 109),
    ("XTS_DATA_UNIT_IS_TOO_LARGE", lib.ERR_LIB_EVP, 191),
    ("XTS_DUPLICATED_KEYS", lib.ERR_LIB_EVP, 192),
    ("ASN1_LEN_EXCEEDS_MAX_RESP_LEN", lib.ERR_LIB_HTTP, 108),
    ("CONNECT_FAILURE", lib.ERR_LIB_HTTP, 100),
    ("ERROR_PARSING_ASN1_LENGTH", lib.ERR_LIB_HTTP, 109),
    ("ERROR_PARSING_CONTENT_LENGTH", lib.ERR_LIB_HTTP, 119),
    ("ERROR_PARSING_URL", lib.ERR_LIB_HTTP, 101),
    ("ERROR_RECEIVING", lib.ERR_LIB_HTTP, 103),
    ("ERROR_SENDING", lib.ERR_LIB_HTTP, 102),
    ("FAILED_READING_DATA", lib.ERR_LIB_HTTP, 128),
    ("HEADER_PARSE_ERROR", lib.ERR_LIB_HTTP, 126),
    ("INCONSISTENT_CONTENT_LENGTH", lib.ERR_LIB_HTTP, 120),
    ("INVALID_PORT_NUMBER", lib.ERR_LIB_HTTP, 123),
    ("INVALID_URL_PATH", lib.ERR_LIB_HTTP, 125),
    ("INVALID_URL_SCHEME", lib.ERR_LIB_HTTP, 124),
    ("MAX_RESP_LEN_EXCEEDED", lib.ERR_LIB_HTTP, 117),
    ("MISSING_ASN1_ENCODING", lib.ERR_LIB_HTTP, 110),
    ("MISSING_CONTENT_TYPE", lib.ERR_LIB_HTTP, 121),
    ("MISSING_REDIRECT_LOCATION", lib.ERR_LIB_HTTP, 111),
    ("RECEIVED_ERROR", lib.ERR_LIB_HTTP, 105),
    ("RECEIVED_WRONG_HTTP_VERSION", lib.ERR_LIB_HTTP, 106),
    ("REDIRECTION_FROM_HTTPS_TO_HTTP", lib.ERR_LIB_HTTP, 112),
    ("REDIRECTION_NOT_ENABLED", lib.ERR_LIB_HTTP, 116),
    ("RESPONSE_LINE_TOO_LONG", lib.ERR_LIB_HTTP, 113),
    ("RESPONSE_PARSE_ERROR", lib.ERR_LIB_HTTP, 104),
    ("SERVER_CANCELED_CONNECTION", lib.ERR_LIB_HTTP, 127),
    ("SOCK_NOT_SUPPORTED", lib.ERR_LIB_HTTP, 122),
    ("STATUS_CODE_UNSUPPORTED", lib.ERR_LIB_HTTP, 114),
    ("TLS_NOT_ENABLED", lib.ERR_LIB_HTTP, 107),
    ("TOO_MANY_REDIRECTIONS", lib.ERR_LIB_HTTP, 115),
    ("UNEXPECTED_CONTENT_TYPE", lib.ERR_LIB_HTTP, 118),
    ("OID_EXISTS", lib.ERR_LIB_OBJ, 102),
    ("UNKNOWN_NID", lib.ERR_LIB_OBJ, 101),
    ("UNKNOWN_OBJECT_NAME", lib.ERR_LIB_OBJ, 103),
    ("CERTIFICATE_VERIFY_ERROR", lib.ERR_LIB_OCSP, 101),
    ("DIGEST_ERR", lib.ERR_LIB_OCSP, 102),
    ("DIGEST_NAME_ERR", lib.ERR_LIB_OCSP, 106),
    ("DIGEST_SIZE_ERR", lib.ERR_LIB_OCSP, 107),
    ("ERROR_IN_NEXTUPDATE_FIELD", lib.ERR_LIB_OCSP, 122),
    ("ERROR_IN_THISUPDATE_FIELD", lib.ERR_LIB_OCSP, 123),
    ("MISSING_OCSPSIGNING_USAGE", lib.ERR_LIB_OCSP, 103),
    ("NEXTUPDATE_BEFORE_THISUPDATE", lib.ERR_LIB_OCSP, 124),
    ("NOT_BASIC_RESPONSE", lib.ERR_LIB_OCSP, 104),
    ("NO_CERTIFICATES_IN_CHAIN", lib.ERR_LIB_OCSP, 105),
    ("NO_RESPONSE_DATA", lib.ERR_LIB_OCSP, 108),
    ("NO_REVOKED_TIME", lib.ERR_LIB_OCSP, 109),
    ("NO_SIGNER_KEY", lib.ERR_LIB_OCSP, 130),
    ("PRIVATE_KEY_DOES_NOT_MATCH_CERTIFICATE", lib.ERR_LIB_OCSP, 110),
    ("REQUEST_NOT_SIGNED", lib.ERR_LIB_OCSP, 128),
    ("RESPONSE_CONTAINS_NO_REVOCATION_DATA", lib.ERR_LIB_OCSP, 111),
    ("ROOT_CA_NOT_TRUSTED", lib.ERR_LIB_OCSP, 112),
    ("SIGNATURE_FAILURE", lib.ERR_LIB_OCSP, 117),
    ("SIGNER_CERTIFICATE_NOT_FOUND", lib.ERR_LIB_OCSP, 118),
    ("STATUS_EXPIRED", lib.ERR_LIB_OCSP, 125),
    ("STATUS_NOT_YET_VALID", lib.ERR_LIB_OCSP, 126),
    ("STATUS_TOO_OLD", lib.ERR_LIB_OCSP, 127),
    ("UNKNOWN_MESSAGE_DIGEST", lib.ERR_LIB_OCSP, 119),
    ("UNKNOWN_NID", lib.ERR_LIB_OCSP, 120),
    ("UNSUPPORTED_REQUESTORNAME_TYPE", lib.ERR_LIB_OCSP, 129),
    ("COULD_NOT_DECODE_OBJECT", lib.ERR_LIB_OSSL_DECODER, 101),
    ("DECODER_NOT_FOUND", lib.ERR_LIB_OSSL_DECODER, 102),
    ("MISSING_GET_PARAMS", lib.ERR_LIB_OSSL_DECODER, 100),
    ("ENCODER_NOT_FOUND", lib.ERR_LIB_OSSL_ENCODER, 101),
    ("INCORRECT_PROPERTY_QUERY", lib.ERR_LIB_OSSL_ENCODER, 100),
    ("MISSING_GET_PARAMS", lib.ERR_LIB_OSSL_ENCODER, 102),
    ("AMBIGUOUS_CONTENT_TYPE", lib.ERR_LIB_OSSL_STORE, 107),
    ("BAD_PASSWORD_READ", lib.ERR_LIB_OSSL_STORE, 115),
    ("ERROR_VERIFYING_PKCS12_MAC", lib.ERR_LIB_OSSL_STORE, 113),
    ("FINGERPRINT_SIZE_DOES_NOT_MATCH_DIGEST", lib.ERR_LIB_OSSL_STORE, 121),
    ("INVALID_SCHEME", lib.ERR_LIB_OSSL_STORE, 106),
    ("IS_NOT_A", lib.ERR_LIB_OSSL_STORE, 112),
    ("LOADER_INCOMPLETE", lib.ERR_LIB_OSSL_STORE, 116),
    ("LOADING_STARTED", lib.ERR_LIB_OSSL_STORE, 117),
    ("NOT_A_CERTIFICATE", lib.ERR_LIB_OSSL_STORE, 100),
    ("NOT_A_CRL", lib.ERR_LIB_OSSL_STORE, 101),
    ("NOT_A_NAME", lib.ERR_LIB_OSSL_STORE, 103),
    ("NOT_A_PRIVATE_KEY", lib.ERR_LIB_OSSL_STORE, 102),
    ("NOT_A_PUBLIC_KEY", lib.ERR_LIB_OSSL_STORE, 122),
    ("NOT_PARAMETERS", lib.ERR_LIB_OSSL_STORE, 104),
    ("NO_LOADERS_FOUND", lib.ERR_LIB_OSSL_STORE, 123),
    ("PASSPHRASE_CALLBACK_ERROR", lib.ERR_LIB_OSSL_STORE, 114),
    ("PATH_MUST_BE_ABSOLUTE", lib.ERR_LIB_OSSL_STORE, 108),
    ("SEARCH_ONLY_SUPPORTED_FOR_DIRECTORIES", lib.ERR_LIB_OSSL_STORE, 119),
    ("UI_PROCESS_INTERRUPTED_OR_CANCELLED", lib.ERR_LIB_OSSL_STORE, 109),
    ("UNREGISTERED_SCHEME", lib.ERR_LIB_OSSL_STORE, 105),
    ("UNSUPPORTED_CONTENT_TYPE", lib.ERR_LIB_OSSL_STORE, 110),
    ("UNSUPPORTED_OPERATION", lib.ERR_LIB_OSSL_STORE, 118),
    ("UNSUPPORTED_SEARCH_TYPE", lib.ERR_LIB_OSSL_STORE, 120),
    ("URI_AUTHORITY_UNSUPPORTED", lib.ERR_LIB_OSSL_STORE, 111),
    ("BAD_BASE64_DECODE", lib.ERR_LIB_PEM, 100),
    ("BAD_DECRYPT", lib.ERR_LIB_PEM, 101),
    ("BAD_END_LINE", lib.ERR_LIB_PEM, 102),
    ("BAD_IV_CHARS", lib.ERR_LIB_PEM, 103),
    ("BAD_MAGIC_NUMBER", lib.ERR_LIB_PEM, 116),
    ("BAD_PASSWORD_READ", lib.ERR_LIB_PEM, 104),
    ("BAD_VERSION_NUMBER", lib.ERR_LIB_PEM, 117),
    ("BIO_WRITE_FAILURE", lib.ERR_LIB_PEM, 118),
    ("CIPHER_IS_NULL", lib.ERR_LIB_PEM, 127),
    ("ERROR_CONVERTING_PRIVATE_KEY", lib.ERR_LIB_PEM, 115),
    ("EXPECTING_DSS_KEY_BLOB", lib.ERR_LIB_PEM, 131),
    ("EXPECTING_PRIVATE_KEY_BLOB", lib.ERR_LIB_PEM, 119),
    ("EXPECTING_PUBLIC_KEY_BLOB", lib.ERR_LIB_PEM, 120),
    ("EXPECTING_RSA_KEY_BLOB", lib.ERR_LIB_PEM, 132),
    ("HEADER_TOO_LONG", lib.ERR_LIB_PEM, 128),
    ("INCONSISTENT_HEADER", lib.ERR_LIB_PEM, 121),
    ("KEYBLOB_HEADER_PARSE_ERROR", lib.ERR_LIB_PEM, 122),
    ("KEYBLOB_TOO_SHORT", lib.ERR_LIB_PEM, 123),
    ("MISSING_DEK_IV", lib.ERR_LIB_PEM, 129),
    ("NOT_DEK_INFO", lib.ERR_LIB_PEM, 105),
    ("NOT_ENCRYPTED", lib.ERR_LIB_PEM, 106),
    ("NOT_PROC_TYPE", lib.ERR_LIB_PEM, 107),
    ("NO_START_LINE", lib.ERR_LIB_PEM, 108),
    ("PROBLEMS_GETTING_PASSWORD", lib.ERR_LIB_PEM, 109),
    ("PVK_DATA_TOO_SHORT", lib.ERR_LIB_PEM, 124),
    ("PVK_TOO_SHORT", lib.ERR_LIB_PEM, 125),
    ("READ_KEY", lib.ERR_LIB_PEM, 111),
    ("SHORT_HEADER", lib.ERR_LIB_PEM, 112),
    ("UNEXPECTED_DEK_IV", lib.ERR_LIB_PEM, 130),
    ("UNSUPPORTED_CIPHER", lib.ERR_LIB_PEM, 113),
    ("UNSUPPORTED_ENCRYPTION", lib.ERR_LIB_PEM, 114),
    ("UNSUPPORTED_KEY_COMPONENTS", lib.ERR_LIB_PEM, 126),
    ("UNSUPPORTED_PUBLIC_KEY_TYPE", lib.ERR_LIB_PEM, 110),
    ("CANT_PACK_STRUCTURE", lib.ERR_LIB_PKCS12, 100),
    ("CONTENT_TYPE_NOT_DATA", lib.ERR_LIB_PKCS12, 121),
    ("DECODE_ERROR", lib.ERR_LIB_PKCS12, 101),
    ("ENCODE_ERROR", lib.ERR_LIB_PKCS12, 102),
    ("ENCRYPT_ERROR", lib.ERR_LIB_PKCS12, 103),
    ("ERROR_SETTING_ENCRYPTED_DATA_TYPE", lib.ERR_LIB_PKCS12, 120),
    ("INVALID_NULL_ARGUMENT", lib.ERR_LIB_PKCS12, 104),
    ("INVALID_NULL_PKCS12_POINTER", lib.ERR_LIB_PKCS12, 105),
    ("INVALID_TYPE", lib.ERR_LIB_PKCS12, 112),
    ("IV_GEN_ERROR", lib.ERR_LIB_PKCS12, 106),
    ("KEY_GEN_ERROR", lib.ERR_LIB_PKCS12, 107),
    ("MAC_ABSENT", lib.ERR_LIB_PKCS12, 108),
    ("MAC_GENERATION_ERROR", lib.ERR_LIB_PKCS12, 109),
    ("MAC_SETUP_ERROR", lib.ERR_LIB_PKCS12, 110),
    ("MAC_STRING_SET_ERROR", lib.ERR_LIB_PKCS12, 111),
    ("MAC_VERIFY_FAILURE", lib.ERR_LIB_PKCS12, 113),
    ("PARSE_ERROR", lib.ERR_LIB_PKCS12, 114),
    ("PKCS12_CIPHERFINAL_ERROR", lib.ERR_LIB_PKCS12, 116),
    ("UNKNOWN_DIGEST_ALGORITHM", lib.ERR_LIB_PKCS12, 118),
    ("UNSUPPORTED_PKCS12_MODE", lib.ERR_LIB_PKCS12, 119),
    ("CERTIFICATE_VERIFY_ERROR", lib.ERR_LIB_PKCS7, 117),
    ("CIPHER_HAS_NO_OBJECT_IDENTIFIER", lib.ERR_LIB_PKCS7, 144),
    ("CIPHER_NOT_INITIALIZED", lib.ERR_LIB_PKCS7, 116),
    ("CONTENT_AND_DATA_PRESENT", lib.ERR_LIB_PKCS7, 118),
    ("CTRL_ERROR", lib.ERR_LIB_PKCS7, 152),
    ("DECRYPT_ERROR", lib.ERR_LIB_PKCS7, 119),
    ("DIGEST_FAILURE", lib.ERR_LIB_PKCS7, 101),
    ("ENCRYPTION_CTRL_FAILURE", lib.ERR_LIB_PKCS7, 149),
    ("ENCRYPTION_NOT_SUPPORTED_FOR_THIS_KEY_TYPE", lib.ERR_LIB_PKCS7, 150),
    ("ERROR_ADDING_RECIPIENT", lib.ERR_LIB_PKCS7, 120),
    ("ERROR_SETTING_CIPHER", lib.ERR_LIB_PKCS7, 121),
    ("INVALID_NULL_POINTER", lib.ERR_LIB_PKCS7, 143),
    ("INVALID_SIGNED_DATA_TYPE", lib.ERR_LIB_PKCS7, 155),
    ("NO_CONTENT", lib.ERR_LIB_PKCS7, 122),
    ("NO_DEFAULT_DIGEST", lib.ERR_LIB_PKCS7, 151),
    ("NO_MATCHING_DIGEST_TYPE_FOUND", lib.ERR_LIB_PKCS7, 154),
    ("NO_RECIPIENT_MATCHES_CERTIFICATE", lib.ERR_LIB_PKCS7, 115),
    ("NO_SIGNATURES_ON_DATA", lib.ERR_LIB_PKCS7, 123),
    ("NO_SIGNERS", lib.ERR_LIB_PKCS7, 142),
    ("OPERATION_NOT_SUPPORTED_ON_THIS_TYPE", lib.ERR_LIB_PKCS7, 104),
    ("PKCS7_ADD_SIGNATURE_ERROR", lib.ERR_LIB_PKCS7, 124),
    ("PKCS7_ADD_SIGNER_ERROR", lib.ERR_LIB_PKCS7, 153),
    ("PKCS7_DATASIGN", lib.ERR_LIB_PKCS7, 145),
    ("PRIVATE_KEY_DOES_NOT_MATCH_CERTIFICATE", lib.ERR_LIB_PKCS7, 127),
    ("SIGNATURE_FAILURE", lib.ERR_LIB_PKCS7, 105),
    ("SIGNER_CERTIFICATE_NOT_FOUND", lib.ERR_LIB_PKCS7, 128),
    ("SIGNING_CTRL_FAILURE", lib.ERR_LIB_PKCS7, 147),
    ("SIGNING_NOT_SUPPORTED_FOR_THIS_KEY_TYPE", lib.ERR_LIB_PKCS7, 148),
    ("SMIME_TEXT_ERROR", lib.ERR_LIB_PKCS7, 129),
    ("UNABLE_TO_FIND_CERTIFICATE", lib.ERR_LIB_PKCS7, 106),
    ("UNABLE_TO_FIND_MEM_BIO", lib.ERR_LIB_PKCS7, 107),
    ("UNABLE_TO_FIND_MESSAGE_DIGEST", lib.ERR_LIB_PKCS7, 108),
    ("UNKNOWN_DIGEST_TYPE", lib.ERR_LIB_PKCS7, 109),
    ("UNKNOWN_OPERATION", lib.ERR_LIB_PKCS7, 110),
    ("UNSUPPORTED_CIPHER_TYPE", lib.ERR_LIB_PKCS7, 111),
    ("UNSUPPORTED_CONTENT_TYPE", lib.ERR_LIB_PKCS7, 112),
    ("WRONG_CONTENT_TYPE", lib.ERR_LIB_PKCS7, 113),
    ("WRONG_PKCS7_TYPE", lib.ERR_LIB_PKCS7, 114),
    ("NAME_TOO_LONG", lib.ERR_LIB_PROP, 100),
    ("NOT_AN_ASCII_CHARACTER", lib.ERR_LIB_PROP, 101),
    ("NOT_AN_HEXADECIMAL_DIGIT", lib.ERR_LIB_PROP, 102),
    ("NOT_AN_IDENTIFIER", lib.ERR_LIB_PROP, 103),
    ("NOT_AN_OCTAL_DIGIT", lib.ERR_LIB_PROP, 104),
    ("NOT_A_DECIMAL_DIGIT", lib.ERR_LIB_PROP, 105),
    ("NO_MATCHING_STRING_DELIMITER", lib.ERR_LIB_PROP, 106),
    ("NO_VALUE", lib.ERR_LIB_PROP, 107),
    ("PARSE_FAILED", lib.ERR_LIB_PROP, 108),
    ("STRING_TOO_LONG", lib.ERR_LIB_PROP, 109),
    ("TRAILING_CHARACTERS", lib.ERR_LIB_PROP, 110),
    ("ADDITIONAL_INPUT_TOO_LONG", lib.ERR_LIB_PROV, 184),
    ("ALGORITHM_MISMATCH", lib.ERR_LIB_PROV, 173),
    ("ALREADY_INSTANTIATED", lib.ERR_LIB_PROV, 185),
    ("BAD_DECRYPT", lib.ERR_LIB_PROV, 100),
    ("BAD_ENCODING", lib.ERR_LIB_PROV, 141),
    ("BAD_LENGTH", lib.ERR_LIB_PROV, 142),
    ("BAD_TLS_CLIENT_VERSION", lib.ERR_LIB_PROV, 161),
    ("BN_ERROR", lib.ERR_LIB_PROV, 160),
    ("CIPHER_OPERATION_FAILED", lib.ERR_LIB_PROV, 102),
    ("DERIVATION_FUNCTION_INIT_FAILED", lib.ERR_LIB_PROV, 205),
    ("DIGEST_NOT_ALLOWED", lib.ERR_LIB_PROV, 174),
    ("ENTROPY_SOURCE_STRENGTH_TOO_WEAK", lib.ERR_LIB_PROV, 186),
    ("ERROR_INSTANTIATING_DRBG", lib.ERR_LIB_PROV, 188),
    ("ERROR_RETRIEVING_ENTROPY", lib.ERR_LIB_PROV, 189),
    ("ERROR_RETRIEVING_NONCE", lib.ERR_LIB_PROV, 190),
    ("FAILED_DURING_DERIVATION", lib.ERR_LIB_PROV, 164),
    ("FAILED_TO_CREATE_LOCK", lib.ERR_LIB_PROV, 180),
    ("FAILED_TO_DECRYPT", lib.ERR_LIB_PROV, 162),
    ("FAILED_TO_GENERATE_KEY", lib.ERR_LIB_PROV, 121),
    ("FAILED_TO_GET_PARAMETER", lib.ERR_LIB_PROV, 103),
    ("FAILED_TO_SET_PARAMETER", lib.ERR_LIB_PROV, 104),
    ("FAILED_TO_SIGN", lib.ERR_LIB_PROV, 175),
    ("FIPS_MODULE_CONDITIONAL_ERROR", lib.ERR_LIB_PROV, 227),
    ("FIPS_MODULE_ENTERING_ERROR_STATE", lib.ERR_LIB_PROV, 224),
    ("FIPS_MODULE_IN_ERROR_STATE", lib.ERR_LIB_PROV, 225),
    ("GENERATE_ERROR", lib.ERR_LIB_PROV, 191),
    ("ILLEGAL_OR_UNSUPPORTED_PADDING_MODE", lib.ERR_LIB_PROV, 165),
    ("INDICATOR_INTEGRITY_FAILURE", lib.ERR_LIB_PROV, 210),
    ("INSUFFICIENT_DRBG_STRENGTH", lib.ERR_LIB_PROV, 181),
    ("INVALID_AAD", lib.ERR_LIB_PROV, 108),
    ("INVALID_CONFIG_DATA", lib.ERR_LIB_PROV, 211),
    ("INVALID_CONSTANT_LENGTH", lib.ERR_LIB_PROV, 157),
    ("INVALID_CURVE", lib.ERR_LIB_PROV, 176),
    ("INVALID_CUSTOM_LENGTH", lib.ERR_LIB_PROV, 111),
    ("INVALID_DATA", lib.ERR_LIB_PROV, 115),
    ("INVALID_DIGEST", lib.ERR_LIB_PROV, 122),
    ("INVALID_DIGEST_LENGTH", lib.ERR_LIB_PROV, 166),
    ("INVALID_DIGEST_SIZE", lib.ERR_LIB_PROV, 218),
    ("INVALID_INPUT_LENGTH", lib.ERR_LIB_PROV, 230),
    ("INVALID_ITERATION_COUNT", lib.ERR_LIB_PROV, 123),
    ("INVALID_IV_LENGTH", lib.ERR_LIB_PROV, 109),
    ("INVALID_KEY", lib.ERR_LIB_PROV, 158),
    ("INVALID_KEY_LENGTH", lib.ERR_LIB_PROV, 105),
    ("INVALID_MAC", lib.ERR_LIB_PROV, 151),
    ("INVALID_MGF1_MD", lib.ERR_LIB_PROV, 167),
    ("INVALID_MODE", lib.ERR_LIB_PROV, 125),
    ("INVALID_OUTPUT_LENGTH", lib.ERR_LIB_PROV, 217),
    ("INVALID_PADDING_MODE", lib.ERR_LIB_PROV, 168),
    ("INVALID_PUBINFO", lib.ERR_LIB_PROV, 198),
    ("INVALID_SALT_LENGTH", lib.ERR_LIB_PROV, 112),
    ("INVALID_SEED_LENGTH", lib.ERR_LIB_PROV, 154),
    ("INVALID_SIGNATURE_SIZE", lib.ERR_LIB_PROV, 179),
    ("INVALID_STATE", lib.ERR_LIB_PROV, 212),
    ("INVALID_TAG", lib.ERR_LIB_PROV, 110),
    ("INVALID_TAG_LENGTH", lib.ERR_LIB_PROV, 118),
    ("INVALID_UKM_LENGTH", lib.ERR_LIB_PROV, 200),
    ("INVALID_X931_DIGEST", lib.ERR_LIB_PROV, 170),
    ("IN_ERROR_STATE", lib.ERR_LIB_PROV, 192),
    ("KEY_SETUP_FAILED", lib.ERR_LIB_PROV, 101),
    ("KEY_SIZE_TOO_SMALL", lib.ERR_LIB_PROV, 171),
    ("LENGTH_TOO_LARGE", lib.ERR_LIB_PROV, 202),
    ("MISMATCHING_DOMAIN_PARAMETERS", lib.ERR_LIB_PROV, 203),
    ("MISSING_CEK_ALG", lib.ERR_LIB_PROV, 144),
    ("MISSING_CIPHER", lib.ERR_LIB_PROV, 155),
    ("MISSING_CONFIG_DATA", lib.ERR_LIB_PROV, 213),
    ("MISSING_CONSTANT", lib.ERR_LIB_PROV, 156),
    ("MISSING_KEY", lib.ERR_LIB_PROV, 128),
    ("MISSING_MAC", lib.ERR_LIB_PROV, 150),
    ("MISSING_MESSAGE_DIGEST", lib.ERR_LIB_PROV, 129),
    ("MISSING_OID", lib.ERR_LIB_PROV, 209),
    ("MISSING_PASS", lib.ERR_LIB_PROV, 130),
    ("MISSING_SALT", lib.ERR_LIB_PROV, 131),
    ("MISSING_SECRET", lib.ERR_LIB_PROV, 132),
    ("MISSING_SEED", lib.ERR_LIB_PROV, 140),
    ("MISSING_SESSION_ID", lib.ERR_LIB_PROV, 133),
    ("MISSING_TYPE", lib.ERR_LIB_PROV, 134),
    ("MISSING_XCGHASH", lib.ERR_LIB_PROV, 135),
    ("MODULE_INTEGRITY_FAILURE", lib.ERR_LIB_PROV, 214),
    ("NOT_A_PRIVATE_KEY", lib.ERR_LIB_PROV, 221),
    ("NOT_A_PUBLIC_KEY", lib.ERR_LIB_PROV, 220),
    ("NOT_INSTANTIATED", lib.ERR_LIB_PROV, 193),
    ("NOT_PARAMETERS", lib.ERR_LIB_PROV, 226),
    ("NOT_SUPPORTED", lib.ERR_LIB_PROV, 136),
    ("NOT_XOF_OR_INVALID_LENGTH", lib.ERR_LIB_PROV, 113),
    ("NO_KEY_SET", lib.ERR_LIB_PROV, 114),
    ("NO_PARAMETERS_SET", lib.ERR_LIB_PROV, 177),
    ("OPERATION_NOT_SUPPORTED_FOR_THIS_KEYTYPE", lib.ERR_LIB_PROV, 178),
    ("OUTPUT_BUFFER_TOO_SMALL", lib.ERR_LIB_PROV, 106),
    ("PARENT_CANNOT_GENERATE_RANDOM_NUMBERS", lib.ERR_LIB_PROV, 228),
    ("PARENT_CANNOT_SUPPLY_ENTROPY_SEED", lib.ERR_LIB_PROV, 187),
    ("PARENT_LOCKING_NOT_ENABLED", lib.ERR_LIB_PROV, 182),
    ("PARENT_STRENGTH_TOO_WEAK", lib.ERR_LIB_PROV, 194),
    ("PATH_MUST_BE_ABSOLUTE", lib.ERR_LIB_PROV, 219),
    ("PERSONALISATION_STRING_TOO_LONG", lib.ERR_LIB_PROV, 195),
    ("PSS_SALTLEN_TOO_SMALL", lib.ERR_LIB_PROV, 172),
    ("REQUEST_TOO_LARGE_FOR_DRBG", lib.ERR_LIB_PROV, 196),
    ("REQUIRE_CTR_MODE_CIPHER", lib.ERR_LIB_PROV, 206),
    ("RESEED_ERROR", lib.ERR_LIB_PROV, 197),
    ("SEARCH_ONLY_SUPPORTED_FOR_DIRECTORIES", lib.ERR_LIB_PROV, 222),
    ("SEED_SOURCES_MUST_NOT_HAVE_A_PARENT", lib.ERR_LIB_PROV, 229),
    ("SELF_TEST_KAT_FAILURE", lib.ERR_LIB_PROV, 215),
    ("SELF_TEST_POST_FAILURE", lib.ERR_LIB_PROV, 216),
    ("TAG_NOT_NEEDED", lib.ERR_LIB_PROV, 120),
    ("TAG_NOT_SET", lib.ERR_LIB_PROV, 119),
    ("TOO_MANY_RECORDS", lib.ERR_LIB_PROV, 126),
    ("UNABLE_TO_FIND_CIPHERS", lib.ERR_LIB_PROV, 207),
    ("UNABLE_TO_GET_PARENT_STRENGTH", lib.ERR_LIB_PROV, 199),
    ("UNABLE_TO_GET_PASSPHRASE", lib.ERR_LIB_PROV, 159),
    ("UNABLE_TO_INITIALISE_CIPHERS", lib.ERR_LIB_PROV, 208),
    ("UNABLE_TO_LOAD_SHA256", lib.ERR_LIB_PROV, 147),
    ("UNABLE_TO_LOCK_PARENT", lib.ERR_LIB_PROV, 201),
    ("UNABLE_TO_RESEED", lib.ERR_LIB_PROV, 204),
    ("UNSUPPORTED_CEK_ALG", lib.ERR_LIB_PROV, 145),
    ("UNSUPPORTED_KEY_SIZE", lib.ERR_LIB_PROV, 153),
    ("UNSUPPORTED_MAC_TYPE", lib.ERR_LIB_PROV, 137),
    ("UNSUPPORTED_NUMBER_OF_ROUNDS", lib.ERR_LIB_PROV, 152),
    ("URI_AUTHORITY_UNSUPPORTED", lib.ERR_LIB_PROV, 223),
    ("VALUE_ERROR", lib.ERR_LIB_PROV, 138),
    ("WRONG_FINAL_BLOCK_LENGTH", lib.ERR_LIB_PROV, 107),
    ("WRONG_OUTPUT_BUFFER_SIZE", lib.ERR_LIB_PROV, 139),
    ("XOF_DIGESTS_NOT_ALLOWED", lib.ERR_LIB_PROV, 183),
    ("XTS_DATA_UNIT_IS_TOO_LARGE", lib.ERR_LIB_PROV, 148),
    ("XTS_DUPLICATED_KEYS", lib.ERR_LIB_PROV, 149),
    ("ADDITIONAL_INPUT_TOO_LONG", lib.ERR_LIB_RAND, 102),
    ("ALREADY_INSTANTIATED", lib.ERR_LIB_RAND, 103),
    ("ARGUMENT_OUT_OF_RANGE", lib.ERR_LIB_RAND, 105),
    ("CANNOT_OPEN_FILE", lib.ERR_LIB_RAND, 121),
    ("DRBG_ALREADY_INITIALIZED", lib.ERR_LIB_RAND, 129),
    ("DRBG_NOT_INITIALISED", lib.ERR_LIB_RAND, 104),
    ("ENTROPY_INPUT_TOO_LONG", lib.ERR_LIB_RAND, 106),
    ("ENTROPY_OUT_OF_RANGE", lib.ERR_LIB_RAND, 124),
    ("ERROR_ENTROPY_POOL_WAS_IGNORED", lib.ERR_LIB_RAND, 127),
    ("ERROR_INITIALISING_DRBG", lib.ERR_LIB_RAND, 107),
    ("ERROR_INSTANTIATING_DRBG", lib.ERR_LIB_RAND, 108),
    ("ERROR_RETRIEVING_ADDITIONAL_INPUT", lib.ERR_LIB_RAND, 109),
    ("ERROR_RETRIEVING_ENTROPY", lib.ERR_LIB_RAND, 110),
    ("ERROR_RETRIEVING_NONCE", lib.ERR_LIB_RAND, 111),
    ("FAILED_TO_CREATE_LOCK", lib.ERR_LIB_RAND, 126),
    ("FUNC_NOT_IMPLEMENTED", lib.ERR_LIB_RAND, 101),
    ("FWRITE_ERROR", lib.ERR_LIB_RAND, 123),
    ("GENERATE_ERROR", lib.ERR_LIB_RAND, 112),
    ("INSUFFICIENT_DRBG_STRENGTH", lib.ERR_LIB_RAND, 139),
    ("INTERNAL_ERROR", lib.ERR_LIB_RAND, 113),
    ("IN_ERROR_STATE", lib.ERR_LIB_RAND, 114),
    ("NOT_A_REGULAR_FILE", lib.ERR_LIB_RAND, 122),
    ("NOT_INSTANTIATED", lib.ERR_LIB_RAND, 115),
    ("NO_DRBG_IMPLEMENTATION_SELECTED", lib.ERR_LIB_RAND, 128),
    ("PARENT_LOCKING_NOT_ENABLED", lib.ERR_LIB_RAND, 130),
    ("PARENT_STRENGTH_TOO_WEAK", lib.ERR_LIB_RAND, 131),
    ("PERSONALISATION_STRING_TOO_LONG", lib.ERR_LIB_RAND, 116),
    ("PREDICTION_RESISTANCE_NOT_SUPPORTED", lib.ERR_LIB_RAND, 133),
    ("PRNG_NOT_SEEDED", lib.ERR_LIB_RAND, 100),
    ("RANDOM_POOL_OVERFLOW", lib.ERR_LIB_RAND, 125),
    ("RANDOM_POOL_UNDERFLOW", lib.ERR_LIB_RAND, 134),
    ("REQUEST_TOO_LARGE_FOR_DRBG", lib.ERR_LIB_RAND, 117),
    ("RESEED_ERROR", lib.ERR_LIB_RAND, 118),
    ("SELFTEST_FAILURE", lib.ERR_LIB_RAND, 119),
    ("TOO_LITTLE_NONCE_REQUESTED", lib.ERR_LIB_RAND, 135),
    ("TOO_MUCH_NONCE_REQUESTED", lib.ERR_LIB_RAND, 136),
    ("UNABLE_TO_CREATE_DRBG", lib.ERR_LIB_RAND, 143),
    ("UNABLE_TO_FETCH_DRBG", lib.ERR_LIB_RAND, 144),
    ("UNABLE_TO_GET_PARENT_RESEED_PROP_COUNTER", lib.ERR_LIB_RAND, 141),
    ("UNABLE_TO_GET_PARENT_STRENGTH", lib.ERR_LIB_RAND, 138),
    ("UNABLE_TO_LOCK_PARENT", lib.ERR_LIB_RAND, 140),
    ("UNSUPPORTED_DRBG_FLAGS", lib.ERR_LIB_RAND, 132),
    ("UNSUPPORTED_DRBG_TYPE", lib.ERR_LIB_RAND, 120),
    ("ALGORITHM_MISMATCH", lib.ERR_LIB_RSA, 100),
    ("BAD_E_VALUE", lib.ERR_LIB_RSA, 101),
    ("BAD_FIXED_HEADER_DECRYPT", lib.ERR_LIB_RSA, 102),
    ("BAD_PAD_BYTE_COUNT", lib.ERR_LIB_RSA, 103),
    ("BAD_SIGNATURE", lib.ERR_LIB_RSA, 104),
    ("BLOCK_TYPE_IS_NOT_01", lib.ERR_LIB_RSA, 106),
    ("BLOCK_TYPE_IS_NOT_02", lib.ERR_LIB_RSA, 107),
    ("DATA_GREATER_THAN_MOD_LEN", lib.ERR_LIB_RSA, 108),
    ("DATA_TOO_LARGE", lib.ERR_LIB_RSA, 109),
    ("DATA_TOO_LARGE_FOR_KEY_SIZE", lib.ERR_LIB_RSA, 110),
    ("DATA_TOO_LARGE_FOR_MODULUS", lib.ERR_LIB_RSA, 132),
    ("DATA_TOO_SMALL", lib.ERR_LIB_RSA, 111),
    ("DATA_TOO_SMALL_FOR_KEY_SIZE", lib.ERR_LIB_RSA, 122),
    ("DIGEST_DOES_NOT_MATCH", lib.ERR_LIB_RSA, 158),
    ("DIGEST_NOT_ALLOWED", lib.ERR_LIB_RSA, 145),
    ("DIGEST_TOO_BIG_FOR_RSA_KEY", lib.ERR_LIB_RSA, 112),
    ("DMP1_NOT_CONGRUENT_TO_D", lib.ERR_LIB_RSA, 124),
    ("DMQ1_NOT_CONGRUENT_TO_D", lib.ERR_LIB_RSA, 125),
    ("D_E_NOT_CONGRUENT_TO_1", lib.ERR_LIB_RSA, 123),
    ("FIRST_OCTET_INVALID", lib.ERR_LIB_RSA, 133),
    ("ILLEGAL_OR_UNSUPPORTED_PADDING_MODE", lib.ERR_LIB_RSA, 144),
    ("INVALID_DIGEST", lib.ERR_LIB_RSA, 157),
    ("INVALID_DIGEST_LENGTH", lib.ERR_LIB_RSA, 143),
    ("INVALID_HEADER", lib.ERR_LIB_RSA, 137),
    ("INVALID_KEYPAIR", lib.ERR_LIB_RSA, 171),
    ("INVALID_KEY_LENGTH", lib.ERR_LIB_RSA, 173),
    ("INVALID_LABEL", lib.ERR_LIB_RSA, 160),
    ("INVALID_LENGTH", lib.ERR_LIB_RSA, 181),
    ("INVALID_MESSAGE_LENGTH", lib.ERR_LIB_RSA, 131),
    ("INVALID_MGF1_MD", lib.ERR_LIB_RSA, 156),
    ("INVALID_MODULUS", lib.ERR_LIB_RSA, 174),
    ("INVALID_MULTI_PRIME_KEY", lib.ERR_LIB_RSA, 167),
    ("INVALID_OAEP_PARAMETERS", lib.ERR_LIB_RSA, 161),
    ("INVALID_PADDING", lib.ERR_LIB_RSA, 138),
    ("INVALID_PADDING_MODE", lib.ERR_LIB_RSA, 141),
    ("INVALID_PSS_PARAMETERS", lib.ERR_LIB_RSA, 149),
    ("INVALID_PSS_SALTLEN", lib.ERR_LIB_RSA, 146),
    ("INVALID_REQUEST", lib.ERR_LIB_RSA, 175),
    ("INVALID_SALT_LENGTH", lib.ERR_LIB_RSA, 150),
    ("INVALID_STRENGTH", lib.ERR_LIB_RSA, 176),
    ("INVALID_TRAILER", lib.ERR_LIB_RSA, 139),
    ("INVALID_X931_DIGEST", lib.ERR_LIB_RSA, 142),
    ("IQMP_NOT_INVERSE_OF_Q", lib.ERR_LIB_RSA, 126),
    ("KEY_PRIME_NUM_INVALID", lib.ERR_LIB_RSA, 165),
    ("KEY_SIZE_TOO_SMALL", lib.ERR_LIB_RSA, 120),
    ("LAST_OCTET_INVALID", lib.ERR_LIB_RSA, 134),
    ("MGF1_DIGEST_NOT_ALLOWED", lib.ERR_LIB_RSA, 152),
    ("MISSING_PRIVATE_KEY", lib.ERR_LIB_RSA, 179),
    ("MODULUS_TOO_LARGE", lib.ERR_LIB_RSA, 105),
    ("MP_COEFFICIENT_NOT_INVERSE_OF_R", lib.ERR_LIB_RSA, 168),
    ("MP_EXPONENT_NOT_CONGRUENT_TO_D", lib.ERR_LIB_RSA, 169),
    ("MP_R_NOT_PRIME", lib.ERR_LIB_RSA, 170),
    ("NO_PUBLIC_EXPONENT", lib.ERR_LIB_RSA, 140),
    ("NULL_BEFORE_BLOCK_MISSING", lib.ERR_LIB_RSA, 113),
    ("N_DOES_NOT_EQUAL_PRODUCT_OF_PRIMES", lib.ERR_LIB_RSA, 172),
    ("N_DOES_NOT_EQUAL_P_Q", lib.ERR_LIB_RSA, 127),
    ("OAEP_DECODING_ERROR", lib.ERR_LIB_RSA, 121),
    ("OPERATION_NOT_SUPPORTED_FOR_THIS_KEYTYPE", lib.ERR_LIB_RSA, 148),
    ("PADDING_CHECK_FAILED", lib.ERR_LIB_RSA, 114),
    ("PAIRWISE_TEST_FAILURE", lib.ERR_LIB_RSA, 177),
    ("PKCS_DECODING_ERROR", lib.ERR_LIB_RSA, 159),
    ("PSS_SALTLEN_TOO_SMALL", lib.ERR_LIB_RSA, 164),
    ("PUB_EXPONENT_OUT_OF_RANGE", lib.ERR_LIB_RSA, 178),
    ("P_NOT_PRIME", lib.ERR_LIB_RSA, 128),
    ("Q_NOT_PRIME", lib.ERR_LIB_RSA, 129),
    ("RANDOMNESS_SOURCE_STRENGTH_INSUFFICIENT", lib.ERR_LIB_RSA, 180),
    ("RSA_OPERATIONS_NOT_SUPPORTED", lib.ERR_LIB_RSA, 130),
    ("SLEN_CHECK_FAILED", lib.ERR_LIB_RSA, 136),
    ("SLEN_RECOVERY_FAILED", lib.ERR_LIB_RSA, 135),
    ("SSLV3_ROLLBACK_ATTACK", lib.ERR_LIB_RSA, 115),
    ("THE_ASN1_OBJECT_IDENTIFIER_IS_NOT_KNOWN_FOR_THIS_MD", lib.ERR_LIB_RSA, 116),
    ("UNKNOWN_ALGORITHM_TYPE", lib.ERR_LIB_RSA, 117),
    ("UNKNOWN_DIGEST", lib.ERR_LIB_RSA, 166),
    ("UNKNOWN_MASK_DIGEST", lib.ERR_LIB_RSA, 151),
    ("UNKNOWN_PADDING_TYPE", lib.ERR_LIB_RSA, 118),
    ("UNSUPPORTED_ENCRYPTION_TYPE", lib.ERR_LIB_RSA, 162),
    ("UNSUPPORTED_LABEL_SOURCE", lib.ERR_LIB_RSA, 163),
    ("UNSUPPORTED_MASK_ALGORITHM", lib.ERR_LIB_RSA, 153),
    ("UNSUPPORTED_MASK_PARAMETER", lib.ERR_LIB_RSA, 154),
    ("UNSUPPORTED_SIGNATURE_TYPE", lib.ERR_LIB_RSA, 155),
    ("VALUE_MISSING", lib.ERR_LIB_RSA, 147),
    ("WRONG_SIGNATURE_LENGTH", lib.ERR_LIB_RSA, 119),
    ("ASN1_ERROR", lib.ERR_LIB_SM2, 100),
    ("BAD_SIGNATURE", lib.ERR_LIB_SM2, 101),
    ("BUFFER_TOO_SMALL", lib.ERR_LIB_SM2, 107),
    ("DIST_ID_TOO_LARGE", lib.ERR_LIB_SM2, 110),
    ("ID_NOT_SET", lib.ERR_LIB_SM2, 112),
    ("ID_TOO_LARGE", lib.ERR_LIB_SM2, 111),
    ("INVALID_CURVE", lib.ERR_LIB_SM2, 108),
    ("INVALID_DIGEST", lib.ERR_LIB_SM2, 102),
    ("INVALID_DIGEST_TYPE", lib.ERR_LIB_SM2, 103),
    ("INVALID_ENCODING", lib.ERR_LIB_SM2, 104),
    ("INVALID_FIELD", lib.ERR_LIB_SM2, 105),
    ("INVALID_PRIVATE_KEY", lib.ERR_LIB_SM2, 113),
    ("NO_PARAMETERS_SET", lib.ERR_LIB_SM2, 109),
    ("USER_ID_TOO_LARGE", lib.ERR_LIB_SM2, 106),
    ("APPLICATION_DATA_AFTER_CLOSE_NOTIFY", lib.ERR_LIB_SSL, 291),
    ("APP_DATA_IN_HANDSHAKE", lib.ERR_LIB_SSL, 100),
    ("ATTEMPT_TO_REUSE_SESSION_IN_DIFFERENT_CONTEXT", lib.ERR_LIB_SSL, 272),
    ("AT_LEAST_TLS_1_2_NEEDED_IN_SUITEB_MODE", lib.ERR_LIB_SSL, 158),
    ("BAD_CHANGE_CIPHER_SPEC", lib.ERR_LIB_SSL, 103),
    ("BAD_CIPHER", lib.ERR_LIB_SSL, 186),
    ("BAD_DATA", lib.ERR_LIB_SSL, 390),
    ("BAD_DATA_RETURNED_BY_CALLBACK", lib.ERR_LIB_SSL, 106),
    ("BAD_DECOMPRESSION", lib.ERR_LIB_SSL, 107),
    ("BAD_DH_VALUE", lib.ERR_LIB_SSL, 102),
    ("BAD_DIGEST_LENGTH", lib.ERR_LIB_SSL, 111),
    ("BAD_EARLY_DATA", lib.ERR_LIB_SSL, 233),
    ("BAD_ECC_CERT", lib.ERR_LIB_SSL, 304),
    ("BAD_ECPOINT", lib.ERR_LIB_SSL, 306),
    ("BAD_EXTENSION", lib.ERR_LIB_SSL, 110),
    ("BAD_HANDSHAKE_LENGTH", lib.ERR_LIB_SSL, 332),
    ("BAD_HANDSHAKE_STATE", lib.ERR_LIB_SSL, 236),
    ("BAD_HELLO_REQUEST", lib.ERR_LIB_SSL, 105),
    ("BAD_HRR_VERSION", lib.ERR_LIB_SSL, 263),
    ("BAD_KEY_SHARE", lib.ERR_LIB_SSL, 108),
    ("BAD_KEY_UPDATE", lib.ERR_LIB_SSL, 122),
    ("BAD_LEGACY_VERSION", lib.ERR_LIB_SSL, 292),
    ("BAD_LENGTH", lib.ERR_LIB_SSL, 271),
    ("BAD_PACKET", lib.ERR_LIB_SSL, 240),
    ("BAD_PACKET_LENGTH", lib.ERR_LIB_SSL, 115),
    ("BAD_PROTOCOL_VERSION_NUMBER", lib.ERR_LIB_SSL, 116),
    ("BAD_PSK", lib.ERR_LIB_SSL, 219),
    ("BAD_PSK_IDENTITY", lib.ERR_LIB_SSL, 114),
    ("BAD_RECORD_TYPE", lib.ERR_LIB_SSL, 443),
    ("BAD_RSA_ENCRYPT", lib.ERR_LIB_SSL, 119),
    ("BAD_SIGNATURE", lib.ERR_LIB_SSL, 123),
    ("BAD_SRP_A_LENGTH", lib.ERR_LIB_SSL, 347),
    ("BAD_SRP_PARAMETERS", lib.ERR_LIB_SSL, 371),
    ("BAD_SRTP_MKI_VALUE", lib.ERR_LIB_SSL, 352),
    ("BAD_SRTP_PROTECTION_PROFILE_LIST", lib.ERR_LIB_SSL, 353),
    ("BAD_SSL_FILETYPE", lib.ERR_LIB_SSL, 124),
    ("BAD_VALUE", lib.ERR_LIB_SSL, 384),
    ("BAD_WRITE_RETRY", lib.ERR_LIB_SSL, 127),
    ("BINDER_DOES_NOT_VERIFY", lib.ERR_LIB_SSL, 253),
    ("BIO_NOT_SET", lib.ERR_LIB_SSL, 128),
    ("BLOCK_CIPHER_PAD_IS_WRONG", lib.ERR_LIB_SSL, 129),
    ("BN_LIB", lib.ERR_LIB_SSL, 130),
    ("CALLBACK_FAILED", lib.ERR_LIB_SSL, 234),
    ("CANNOT_CHANGE_CIPHER", lib.ERR_LIB_SSL, 109),
    ("CANNOT_GET_GROUP_NAME", lib.ERR_LIB_SSL, 299),
    ("CA_DN_LENGTH_MISMATCH", lib.ERR_LIB_SSL, 131),
    ("CA_KEY_TOO_SMALL", lib.ERR_LIB_SSL, 397),
    ("CA_MD_TOO_WEAK", lib.ERR_LIB_SSL, 398),
    ("CCS_RECEIVED_EARLY", lib.ERR_LIB_SSL, 133),
    ("CERTIFICATE_VERIFY_FAILED", lib.ERR_LIB_SSL, 134),
    ("CERT_CB_ERROR", lib.ERR_LIB_SSL, 377),
    ("CERT_LENGTH_MISMATCH", lib.ERR_LIB_SSL, 135),
    ("CIPHERSUITE_DIGEST_HAS_CHANGED", lib.ERR_LIB_SSL, 218),
    ("CIPHER_CODE_WRONG_LENGTH", lib.ERR_LIB_SSL, 137),
    ("CLIENTHELLO_TLSEXT", lib.ERR_LIB_SSL, 226),
    ("COMPRESSED_LENGTH_TOO_LONG", lib.ERR_LIB_SSL, 140),
    ("COMPRESSION_DISABLED", lib.ERR_LIB_SSL, 343),
    ("COMPRESSION_FAILURE", lib.ERR_LIB_SSL, 141),
    ("COMPRESSION_ID_NOT_WITHIN_PRIVATE_RANGE", lib.ERR_LIB_SSL, 307),
    ("COMPRESSION_LIBRARY_ERROR", lib.ERR_LIB_SSL, 142),
    ("CONNECTION_TYPE_NOT_SET", lib.ERR_LIB_SSL, 144),
    ("CONTEXT_NOT_DANE_ENABLED", lib.ERR_LIB_SSL, 167),
    ("COOKIE_GEN_CALLBACK_FAILURE", lib.ERR_LIB_SSL, 400),
    ("COOKIE_MISMATCH", lib.ERR_LIB_SSL, 308),
    ("COPY_PARAMETERS_FAILED", lib.ERR_LIB_SSL, 296),
    ("CUSTOM_EXT_HANDLER_ALREADY_INSTALLED", lib.ERR_LIB_SSL, 206),
    ("DANE_ALREADY_ENABLED", lib.ERR_LIB_SSL, 172),
    ("DANE_CANNOT_OVERRIDE_MTYPE_FULL", lib.ERR_LIB_SSL, 173),
    ("DANE_NOT_ENABLED", lib.ERR_LIB_SSL, 175),
    ("DANE_TLSA_BAD_CERTIFICATE", lib.ERR_LIB_SSL, 180),
    ("DANE_TLSA_BAD_CERTIFICATE_USAGE", lib.ERR_LIB_SSL, 184),
    ("DANE_TLSA_BAD_DATA_LENGTH", lib.ERR_LIB_SSL, 189),
    ("DANE_TLSA_BAD_DIGEST_LENGTH", lib.ERR_LIB_SSL, 192),
    ("DANE_TLSA_BAD_MATCHING_TYPE", lib.ERR_LIB_SSL, 200),
    ("DANE_TLSA_BAD_PUBLIC_KEY", lib.ERR_LIB_SSL, 201),
    ("DANE_TLSA_BAD_SELECTOR", lib.ERR_LIB_SSL, 202),
    ("DANE_TLSA_NULL_DATA", lib.ERR_LIB_SSL, 203),
    ("DATA_BETWEEN_CCS_AND_FINISHED", lib.ERR_LIB_SSL, 145),
    ("DATA_LENGTH_TOO_LONG", lib.ERR_LIB_SSL, 146),
    ("DECRYPTION_FAILED", lib.ERR_LIB_SSL, 147),
    ("DECRYPTION_FAILED_OR_BAD_RECORD_MAC", lib.ERR_LIB_SSL, 281),
    ("DH_KEY_TOO_SMALL", lib.ERR_LIB_SSL, 394),
    ("DH_PUBLIC_VALUE_LENGTH_IS_WRONG", lib.ERR_LIB_SSL, 148),
    ("DIGEST_CHECK_FAILED", lib.ERR_LIB_SSL, 149),
    ("DTLS_MESSAGE_TOO_BIG", lib.ERR_LIB_SSL, 334),
    ("DUPLICATE_COMPRESSION_ID", lib.ERR_LIB_SSL, 309),
    ("ECC_CERT_NOT_FOR_SIGNING", lib.ERR_LIB_SSL, 318),
    ("ECDH_REQUIRED_FOR_SUITEB_MODE", lib.ERR_LIB_SSL, 374),
    ("EE_KEY_TOO_SMALL", lib.ERR_LIB_SSL, 399),
    ("EMPTY_SRTP_PROTECTION_PROFILE_LIST", lib.ERR_LIB_SSL, 354),
    ("ENCRYPTED_LENGTH_TOO_LONG", lib.ERR_LIB_SSL, 150),
    ("ERROR_IN_RECEIVED_CIPHER_LIST", lib.ERR_LIB_SSL, 151),
    ("ERROR_SETTING_TLSA_BASE_DOMAIN", lib.ERR_LIB_SSL, 204),
    ("EXCEEDS_MAX_FRAGMENT_SIZE", lib.ERR_LIB_SSL, 194),
    ("EXCESSIVE_MESSAGE_SIZE", lib.ERR_LIB_SSL, 152),
    ("EXTENSION_NOT_RECEIVED", lib.ERR_LIB_SSL, 279),
    ("EXTRA_DATA_IN_MESSAGE", lib.ERR_LIB_SSL, 153),
    ("EXT_LENGTH_MISMATCH", lib.ERR_LIB_SSL, 163),
    ("FAILED_TO_INIT_ASYNC", lib.ERR_LIB_SSL, 405),
    ("FRAGMENTED_CLIENT_HELLO", lib.ERR_LIB_SSL, 401),
    ("GOT_A_FIN_BEFORE_A_CCS", lib.ERR_LIB_SSL, 154),
    ("HTTPS_PROXY_REQUEST", lib.ERR_LIB_SSL, 155),
    ("HTTP_REQUEST", lib.ERR_LIB_SSL, 156),
    ("ILLEGAL_POINT_COMPRESSION", lib.ERR_LIB_SSL, 162),
    ("ILLEGAL_SUITEB_DIGEST", lib.ERR_LIB_SSL, 380),
    ("INAPPROPRIATE_FALLBACK", lib.ERR_LIB_SSL, 373),
    ("INCONSISTENT_COMPRESSION", lib.ERR_LIB_SSL, 340),
    ("INCONSISTENT_EARLY_DATA_ALPN", lib.ERR_LIB_SSL, 222),
    ("INCONSISTENT_EARLY_DATA_SNI", lib.ERR_LIB_SSL, 231),
    ("INCONSISTENT_EXTMS", lib.ERR_LIB_SSL, 104),
    ("INSUFFICIENT_SECURITY", lib.ERR_LIB_SSL, 241),
    ("INVALID_ALERT", lib.ERR_LIB_SSL, 205),
    ("INVALID_CCS_MESSAGE", lib.ERR_LIB_SSL, 260),
    ("INVALID_CERTIFICATE_OR_ALG", lib.ERR_LIB_SSL, 238),
    ("INVALID_COMMAND", lib.ERR_LIB_SSL, 280),
    ("INVALID_COMPRESSION_ALGORITHM", lib.ERR_LIB_SSL, 341),
    ("INVALID_CONFIG", lib.ERR_LIB_SSL, 283),
    ("INVALID_CONFIGURATION_NAME", lib.ERR_LIB_SSL, 113),
    ("INVALID_CONTEXT", lib.ERR_LIB_SSL, 282),
    ("INVALID_CT_VALIDATION_TYPE", lib.ERR_LIB_SSL, 212),
    ("INVALID_KEY_UPDATE_TYPE", lib.ERR_LIB_SSL, 120),
    ("INVALID_MAX_EARLY_DATA", lib.ERR_LIB_SSL, 174),
    ("INVALID_NULL_CMD_NAME", lib.ERR_LIB_SSL, 385),
    ("INVALID_SEQUENCE_NUMBER", lib.ERR_LIB_SSL, 402),
    ("INVALID_SERVERINFO_DATA", lib.ERR_LIB_SSL, 388),
    ("INVALID_SESSION_ID", lib.ERR_LIB_SSL, 999),
    ("INVALID_SRP_USERNAME", lib.ERR_LIB_SSL, 357),
    ("INVALID_STATUS_RESPONSE", lib.ERR_LIB_SSL, 328),
    ("INVALID_TICKET_KEYS_LENGTH", lib.ERR_LIB_SSL, 325),
    ("LENGTH_MISMATCH", lib.ERR_LIB_SSL, 159),
    ("LENGTH_TOO_LONG", lib.ERR_LIB_SSL, 404),
    ("LENGTH_TOO_SHORT", lib.ERR_LIB_SSL, 160),
    ("LIBRARY_BUG", lib.ERR_LIB_SSL, 274),
    ("LIBRARY_HAS_NO_CIPHERS", lib.ERR_LIB_SSL, 161),
    ("MISSING_DSA_SIGNING_CERT", lib.ERR_LIB_SSL, 165),
    ("MISSING_ECDSA_SIGNING_CERT", lib.ERR_LIB_SSL, 381),
    ("MISSING_FATAL", lib.ERR_LIB_SSL, 256),
    ("MISSING_PARAMETERS", lib.ERR_LIB_SSL, 290),
    ("MISSING_PSK_KEX_MODES_EXTENSION", lib.ERR_LIB_SSL, 310),
    ("MISSING_RSA_CERTIFICATE", lib.ERR_LIB_SSL, 168),
    ("MISSING_RSA_ENCRYPTING_CERT", lib.ERR_LIB_SSL, 169),
    ("MISSING_RSA_SIGNING_CERT", lib.ERR_LIB_SSL, 170),
    ("MISSING_SIGALGS_EXTENSION", lib.ERR_LIB_SSL, 112),
    ("MISSING_SIGNING_CERT", lib.ERR_LIB_SSL, 221),
    ("MISSING_SRP_PARAM", lib.ERR_LIB_SSL, 358),
    ("MISSING_SUPPORTED_GROUPS_EXTENSION", lib.ERR_LIB_SSL, 209),
    ("MISSING_TMP_DH_KEY", lib.ERR_LIB_SSL, 171),
    ("MISSING_TMP_ECDH_KEY", lib.ERR_LIB_SSL, 311),
    ("MIXED_HANDSHAKE_AND_NON_HANDSHAKE_DATA", lib.ERR_LIB_SSL, 293),
    ("NOT_ON_RECORD_BOUNDARY", lib.ERR_LIB_SSL, 182),
    ("NOT_REPLACING_CERTIFICATE", lib.ERR_LIB_SSL, 289),
    ("NOT_SERVER", lib.ERR_LIB_SSL, 284),
    ("NO_APPLICATION_PROTOCOL", lib.ERR_LIB_SSL, 235),
    ("NO_CERTIFICATES_RETURNED", lib.ERR_LIB_SSL, 176),
    ("NO_CERTIFICATE_ASSIGNED", lib.ERR_LIB_SSL, 177),
    ("NO_CERTIFICATE_SET", lib.ERR_LIB_SSL, 179),
    ("NO_CHANGE_FOLLOWING_HRR", lib.ERR_LIB_SSL, 214),
    ("NO_CIPHERS_AVAILABLE", lib.ERR_LIB_SSL, 181),
    ("NO_CIPHERS_SPECIFIED", lib.ERR_LIB_SSL, 183),
    ("NO_CIPHER_MATCH", lib.ERR_LIB_SSL, 185),
    ("NO_CLIENT_CERT_METHOD", lib.ERR_LIB_SSL, 331),
    ("NO_COMPRESSION_SPECIFIED", lib.ERR_LIB_SSL, 187),
    ("NO_COOKIE_CALLBACK_SET", lib.ERR_LIB_SSL, 287),
    ("NO_GOST_CERTIFICATE_SENT_BY_PEER", lib.ERR_LIB_SSL, 330),
    ("NO_METHOD_SPECIFIED", lib.ERR_LIB_SSL, 188),
    ("NO_PEM_EXTENSIONS", lib.ERR_LIB_SSL, 389),
    ("NO_PRIVATE_KEY_ASSIGNED", lib.ERR_LIB_SSL, 190),
    ("NO_PROTOCOLS_AVAILABLE", lib.ERR_LIB_SSL, 191),
    ("NO_RENEGOTIATION", lib.ERR_LIB_SSL, 339),
    ("NO_REQUIRED_DIGEST", lib.ERR_LIB_SSL, 324),
    ("NO_SHARED_CIPHER", lib.ERR_LIB_SSL, 193),
    ("NO_SHARED_GROUPS", lib.ERR_LIB_SSL, 410),
    ("NO_SHARED_SIGNATURE_ALGORITHMS", lib.ERR_LIB_SSL, 376),
    ("NO_SRTP_PROFILES", lib.ERR_LIB_SSL, 359),
    ("NO_SUITABLE_DIGEST_ALGORITHM", lib.ERR_LIB_SSL, 297),
    ("NO_SUITABLE_GROUPS", lib.ERR_LIB_SSL, 295),
    ("NO_SUITABLE_KEY_SHARE", lib.ERR_LIB_SSL, 101),
    ("NO_SUITABLE_SIGNATURE_ALGORITHM", lib.ERR_LIB_SSL, 118),
    ("NO_VALID_SCTS", lib.ERR_LIB_SSL, 216),
    ("NO_VERIFY_COOKIE_CALLBACK", lib.ERR_LIB_SSL, 403),
    ("NULL_SSL_CTX", lib.ERR_LIB_SSL, 195),
    ("NULL_SSL_METHOD_PASSED", lib.ERR_LIB_SSL, 196),
    ("OCSP_CALLBACK_FAILURE", lib.ERR_LIB_SSL, 305),
    ("OLD_SESSION_CIPHER_NOT_RETURNED", lib.ERR_LIB_SSL, 197),
    ("OLD_SESSION_COMPRESSION_ALGORITHM_NOT_RETURNED", lib.ERR_LIB_SSL, 344),
    ("OVERFLOW_ERROR", lib.ERR_LIB_SSL, 237),
    ("PACKET_LENGTH_TOO_LONG", lib.ERR_LIB_SSL, 198),
    ("PARSE_TLSEXT", lib.ERR_LIB_SSL, 227),
    ("PATH_TOO_LONG", lib.ERR_LIB_SSL, 270),
    ("PEER_DID_NOT_RETURN_A_CERTIFICATE", lib.ERR_LIB_SSL, 199),
    ("PEM_NAME_BAD_PREFIX", lib.ERR_LIB_SSL, 391),
    ("PEM_NAME_TOO_SHORT", lib.ERR_LIB_SSL, 392),
    ("PIPELINE_FAILURE", lib.ERR_LIB_SSL, 406),
    ("POST_HANDSHAKE_AUTH_ENCODING_ERR", lib.ERR_LIB_SSL, 278),
    ("PRIVATE_KEY_MISMATCH", lib.ERR_LIB_SSL, 288),
    ("PROTOCOL_IS_SHUTDOWN", lib.ERR_LIB_SSL, 207),
    ("PSK_IDENTITY_NOT_FOUND", lib.ERR_LIB_SSL, 223),
    ("PSK_NO_CLIENT_CB", lib.ERR_LIB_SSL, 224),
    ("PSK_NO_SERVER_CB", lib.ERR_LIB_SSL, 225),
    ("READ_BIO_NOT_SET", lib.ERR_LIB_SSL, 211),
    ("READ_TIMEOUT_EXPIRED", lib.ERR_LIB_SSL, 312),
    ("RECORD_LENGTH_MISMATCH", lib.ERR_LIB_SSL, 213),
    ("RECORD_TOO_SMALL", lib.ERR_LIB_SSL, 298),
    ("RENEGOTIATE_EXT_TOO_LONG", lib.ERR_LIB_SSL, 335),
    ("RENEGOTIATION_ENCODING_ERR", lib.ERR_LIB_SSL, 336),
    ("RENEGOTIATION_MISMATCH", lib.ERR_LIB_SSL, 337),
    ("REQUEST_PENDING", lib.ERR_LIB_SSL, 285),
    ("REQUEST_SENT", lib.ERR_LIB_SSL, 286),
    ("REQUIRED_CIPHER_MISSING", lib.ERR_LIB_SSL, 215),
    ("REQUIRED_COMPRESSION_ALGORITHM_MISSING", lib.ERR_LIB_SSL, 342),
    ("SCSV_RECEIVED_WHEN_RENEGOTIATING", lib.ERR_LIB_SSL, 345),
    ("SCT_VERIFICATION_FAILED", lib.ERR_LIB_SSL, 208),
    ("SERVERHELLO_TLSEXT", lib.ERR_LIB_SSL, 275),
    ("SESSION_ID_CONTEXT_UNINITIALIZED", lib.ERR_LIB_SSL, 277),
    ("SHUTDOWN_WHILE_IN_INIT", lib.ERR_LIB_SSL, 407),
    ("SIGNATURE_ALGORITHMS_ERROR", lib.ERR_LIB_SSL, 360),
    ("SIGNATURE_FOR_NON_SIGNING_CERTIFICATE", lib.ERR_LIB_SSL, 220),
    ("SRP_A_CALC", lib.ERR_LIB_SSL, 361),
    ("SRTP_COULD_NOT_ALLOCATE_PROFILES", lib.ERR_LIB_SSL, 362),
    ("SRTP_PROTECTION_PROFILE_LIST_TOO_LONG", lib.ERR_LIB_SSL, 363),
    ("SRTP_UNKNOWN_PROTECTION_PROFILE", lib.ERR_LIB_SSL, 364),
    ("SSL3_EXT_INVALID_MAX_FRAGMENT_LENGTH", lib.ERR_LIB_SSL, 232),
    ("SSL3_EXT_INVALID_SERVERNAME", lib.ERR_LIB_SSL, 319),
    ("SSL3_EXT_INVALID_SERVERNAME_TYPE", lib.ERR_LIB_SSL, 320),
    ("SSL3_SESSION_ID_TOO_LONG", lib.ERR_LIB_SSL, 300),
    ("SSLV3_ALERT_BAD_CERTIFICATE", lib.ERR_LIB_SSL, 1042),
    ("SSLV3_ALERT_BAD_RECORD_MAC", lib.ERR_LIB_SSL, 1020),
    ("SSLV3_ALERT_CERTIFICATE_EXPIRED", lib.ERR_LIB_SSL, 1045),
    ("SSLV3_ALERT_CERTIFICATE_REVOKED", lib.ERR_LIB_SSL, 1044),
    ("SSLV3_ALERT_CERTIFICATE_UNKNOWN", lib.ERR_LIB_SSL, 1046),
    ("SSLV3_ALERT_DECOMPRESSION_FAILURE", lib.ERR_LIB_SSL, 1030),
    ("SSLV3_ALERT_HANDSHAKE_FAILURE", lib.ERR_LIB_SSL, 1040),
    ("SSLV3_ALERT_ILLEGAL_PARAMETER", lib.ERR_LIB_SSL, 1047),
    ("SSLV3_ALERT_NO_CERTIFICATE", lib.ERR_LIB_SSL, 1041),
    ("SSLV3_ALERT_UNEXPECTED_MESSAGE", lib.ERR_LIB_SSL, 1010),
    ("SSLV3_ALERT_UNSUPPORTED_CERTIFICATE", lib.ERR_LIB_SSL, 1043),
    ("SSL_COMMAND_SECTION_EMPTY", lib.ERR_LIB_SSL, 117),
    ("SSL_COMMAND_SECTION_NOT_FOUND", lib.ERR_LIB_SSL, 125),
    ("SSL_CTX_HAS_NO_DEFAULT_SSL_VERSION", lib.ERR_LIB_SSL, 228),
    ("SSL_HANDSHAKE_FAILURE", lib.ERR_LIB_SSL, 229),
    ("SSL_LIBRARY_HAS_NO_CIPHERS", lib.ERR_LIB_SSL, 230),
    ("SSL_NEGATIVE_LENGTH", lib.ERR_LIB_SSL, 372),
    ("SSL_SECTION_EMPTY", lib.ERR_LIB_SSL, 126),
    ("SSL_SECTION_NOT_FOUND", lib.ERR_LIB_SSL, 136),
    ("SSL_SESSION_ID_CALLBACK_FAILED", lib.ERR_LIB_SSL, 301),
    ("SSL_SESSION_ID_CONFLICT", lib.ERR_LIB_SSL, 302),
    ("SSL_SESSION_ID_CONTEXT_TOO_LONG", lib.ERR_LIB_SSL, 273),
    ("SSL_SESSION_ID_HAS_BAD_LENGTH", lib.ERR_LIB_SSL, 303),
    ("SSL_SESSION_ID_TOO_LONG", lib.ERR_LIB_SSL, 408),
    ("SSL_SESSION_VERSION_MISMATCH", lib.ERR_LIB_SSL, 210),
    ("STILL_IN_INIT", lib.ERR_LIB_SSL, 121),
    ("TLSV13_ALERT_CERTIFICATE_REQUIRED", lib.ERR_LIB_SSL, 1116),
    ("TLSV13_ALERT_MISSING_EXTENSION", lib.ERR_LIB_SSL, 1109),
    ("TLSV1_ALERT_ACCESS_DENIED", lib.ERR_LIB_SSL, 1049),
    ("TLSV1_ALERT_DECODE_ERROR", lib.ERR_LIB_SSL, 1050),
    ("TLSV1_ALERT_DECRYPTION_FAILED", lib.ERR_LIB_SSL, 1021),
    ("TLSV1_ALERT_DECRYPT_ERROR", lib.ERR_LIB_SSL, 1051),
    ("TLSV1_ALERT_EXPORT_RESTRICTION", lib.ERR_LIB_SSL, 1060),
    ("TLSV1_ALERT_INAPPROPRIATE_FALLBACK", lib.ERR_LIB_SSL, 1086),
    ("TLSV1_ALERT_INSUFFICIENT_SECURITY", lib.ERR_LIB_SSL, 1071),
    ("TLSV1_ALERT_INTERNAL_ERROR", lib.ERR_LIB_SSL, 1080),
    ("TLSV1_ALERT_NO_RENEGOTIATION", lib.ERR_LIB_SSL, 1100),
    ("TLSV1_ALERT_PROTOCOL_VERSION", lib.ERR_LIB_SSL, 1070),
    ("TLSV1_ALERT_RECORD_OVERFLOW", lib.ERR_LIB_SSL, 1022),
    ("TLSV1_ALERT_UNKNOWN_CA", lib.ERR_LIB_SSL, 1048),
    ("TLSV1_ALERT_USER_CANCELLED", lib.ERR_LIB_SSL, 1090),
    ("TLSV1_BAD_CERTIFICATE_HASH_VALUE", lib.ERR_LIB_SSL, 1114),
    ("TLSV1_BAD_CERTIFICATE_STATUS_RESPONSE", lib.ERR_LIB_SSL, 1113),
    ("TLSV1_CERTIFICATE_UNOBTAINABLE", lib.ERR_LIB_SSL, 1111),
    ("TLSV1_UNRECOGNIZED_NAME", lib.ERR_LIB_SSL, 1112),
    ("TLSV1_UNSUPPORTED_EXTENSION", lib.ERR_LIB_SSL, 1110),
    ("TLS_ILLEGAL_EXPORTER_LABEL", lib.ERR_LIB_SSL, 367),
    ("TLS_INVALID_ECPOINTFORMAT_LIST", lib.ERR_LIB_SSL, 157),
    ("TOO_MANY_KEY_UPDATES", lib.ERR_LIB_SSL, 132),
    ("TOO_MANY_WARN_ALERTS", lib.ERR_LIB_SSL, 409),
    ("TOO_MUCH_EARLY_DATA", lib.ERR_LIB_SSL, 164),
    ("UNABLE_TO_FIND_ECDH_PARAMETERS", lib.ERR_LIB_SSL, 314),
    ("UNABLE_TO_FIND_PUBLIC_KEY_PARAMETERS", lib.ERR_LIB_SSL, 239),
    ("UNABLE_TO_LOAD_SSL3_MD5_ROUTINES", lib.ERR_LIB_SSL, 242),
    ("UNABLE_TO_LOAD_SSL3_SHA1_ROUTINES", lib.ERR_LIB_SSL, 243),
    ("UNEXPECTED_CCS_MESSAGE", lib.ERR_LIB_SSL, 262),
    ("UNEXPECTED_END_OF_EARLY_DATA", lib.ERR_LIB_SSL, 178),
    ("UNEXPECTED_EOF_WHILE_READING", lib.ERR_LIB_SSL, 294),
    ("UNEXPECTED_MESSAGE", lib.ERR_LIB_SSL, 244),
    ("UNEXPECTED_RECORD", lib.ERR_LIB_SSL, 245),
    ("UNINITIALIZED", lib.ERR_LIB_SSL, 276),
    ("UNKNOWN_ALERT_TYPE", lib.ERR_LIB_SSL, 246),
    ("UNKNOWN_CERTIFICATE_TYPE", lib.ERR_LIB_SSL, 247),
    ("UNKNOWN_CIPHER_RETURNED", lib.ERR_LIB_SSL, 248),
    ("UNKNOWN_CIPHER_TYPE", lib.ERR_LIB_SSL, 249),
    ("UNKNOWN_CMD_NAME", lib.ERR_LIB_SSL, 386),
    ("UNKNOWN_COMMAND", lib.ERR_LIB_SSL, 139),
    ("UNKNOWN_DIGEST", lib.ERR_LIB_SSL, 368),
    ("UNKNOWN_KEY_EXCHANGE_TYPE", lib.ERR_LIB_SSL, 250),
    ("UNKNOWN_PKEY_TYPE", lib.ERR_LIB_SSL, 251),
    ("UNKNOWN_PROTOCOL", lib.ERR_LIB_SSL, 252),
    ("UNKNOWN_SSL_VERSION", lib.ERR_LIB_SSL, 254),
    ("UNKNOWN_STATE", lib.ERR_LIB_SSL, 255),
    ("UNSAFE_LEGACY_RENEGOTIATION_DISABLED", lib.ERR_LIB_SSL, 338),
    ("UNSOLICITED_EXTENSION", lib.ERR_LIB_SSL, 217),
    ("UNSUPPORTED_COMPRESSION_ALGORITHM", lib.ERR_LIB_SSL, 257),
    ("UNSUPPORTED_ELLIPTIC_CURVE", lib.ERR_LIB_SSL, 315),
    ("UNSUPPORTED_PROTOCOL", lib.ERR_LIB_SSL, 258),
    ("UNSUPPORTED_SSL_VERSION", lib.ERR_LIB_SSL, 259),
    ("UNSUPPORTED_STATUS_TYPE", lib.ERR_LIB_SSL, 329),
    ("USE_SRTP_NOT_NEGOTIATED", lib.ERR_LIB_SSL, 369),
    ("VERSION_TOO_HIGH", lib.ERR_LIB_SSL, 166),
    ("VERSION_TOO_LOW", lib.ERR_LIB_SSL, 396),
    ("WRONG_CERTIFICATE_TYPE", lib.ERR_LIB_SSL, 383),
    ("WRONG_CIPHER_RETURNED", lib.ERR_LIB_SSL, 261),
    ("WRONG_CURVE", lib.ERR_LIB_SSL, 378),
    ("WRONG_SIGNATURE_LENGTH", lib.ERR_LIB_SSL, 264),
    ("WRONG_SIGNATURE_SIZE", lib.ERR_LIB_SSL, 265),
    ("WRONG_SIGNATURE_TYPE", lib.ERR_LIB_SSL, 370),
    ("WRONG_SSL_VERSION", lib.ERR_LIB_SSL, 266),
    ("WRONG_VERSION_NUMBER", lib.ERR_LIB_SSL, 267),
    ("X509_LIB", lib.ERR_LIB_SSL, 268),
    ("X509_VERIFICATION_SETUP_PROBLEMS", lib.ERR_LIB_SSL, 269),
    ("BAD_PKCS7_TYPE", lib.ERR_LIB_TS, 132),
    ("BAD_TYPE", lib.ERR_LIB_TS, 133),
    ("CANNOT_LOAD_CERT", lib.ERR_LIB_TS, 137),
    ("CANNOT_LOAD_KEY", lib.ERR_LIB_TS, 138),
    ("CERTIFICATE_VERIFY_ERROR", lib.ERR_LIB_TS, 100),
    ("COULD_NOT_SET_ENGINE", lib.ERR_LIB_TS, 127),
    ("COULD_NOT_SET_TIME", lib.ERR_LIB_TS, 115),
    ("DETACHED_CONTENT", lib.ERR_LIB_TS, 134),
    ("ESS_ADD_SIGNING_CERT_ERROR", lib.ERR_LIB_TS, 116),
    ("ESS_ADD_SIGNING_CERT_V2_ERROR", lib.ERR_LIB_TS, 139),
    ("ESS_SIGNING_CERTIFICATE_ERROR", lib.ERR_LIB_TS, 101),
    ("INVALID_NULL_POINTER", lib.ERR_LIB_TS, 102),
    ("INVALID_SIGNER_CERTIFICATE_PURPOSE", lib.ERR_LIB_TS, 117),
    ("MESSAGE_IMPRINT_MISMATCH", lib.ERR_LIB_TS, 103),
    ("NONCE_MISMATCH", lib.ERR_LIB_TS, 104),
    ("NONCE_NOT_RETURNED", lib.ERR_LIB_TS, 105),
    ("NO_CONTENT", lib.ERR_LIB_TS, 106),
    ("NO_TIME_STAMP_TOKEN", lib.ERR_LIB_TS, 107),
    ("PKCS7_ADD_SIGNATURE_ERROR", lib.ERR_LIB_TS, 118),
    ("PKCS7_ADD_SIGNED_ATTR_ERROR", lib.ERR_LIB_TS, 119),
    ("PKCS7_TO_TS_TST_INFO_FAILED", lib.ERR_LIB_TS, 129),
    ("POLICY_MISMATCH", lib.ERR_LIB_TS, 108),
    ("PRIVATE_KEY_DOES_NOT_MATCH_CERTIFICATE", lib.ERR_LIB_TS, 120),
    ("RESPONSE_SETUP_ERROR", lib.ERR_LIB_TS, 121),
    ("SIGNATURE_FAILURE", lib.ERR_LIB_TS, 109),
    ("THERE_MUST_BE_ONE_SIGNER", lib.ERR_LIB_TS, 110),
    ("TIME_SYSCALL_ERROR", lib.ERR_LIB_TS, 122),
    ("TOKEN_NOT_PRESENT", lib.ERR_LIB_TS, 130),
    ("TOKEN_PRESENT", lib.ERR_LIB_TS, 131),
    ("TSA_NAME_MISMATCH", lib.ERR_LIB_TS, 111),
    ("TSA_UNTRUSTED", lib.ERR_LIB_TS, 112),
    ("TST_INFO_SETUP_ERROR", lib.ERR_LIB_TS, 123),
    ("TS_DATASIGN", lib.ERR_LIB_TS, 124),
    ("UNACCEPTABLE_POLICY", lib.ERR_LIB_TS, 125),
    ("UNSUPPORTED_MD_ALGORITHM", lib.ERR_LIB_TS, 126),
    ("UNSUPPORTED_VERSION", lib.ERR_LIB_TS, 113),
    ("VAR_BAD_VALUE", lib.ERR_LIB_TS, 135),
    ("VAR_LOOKUP_FAILURE", lib.ERR_LIB_TS, 136),
    ("WRONG_CONTENT_TYPE", lib.ERR_LIB_TS, 114),
    ("COMMON_OK_AND_CANCEL_CHARACTERS", lib.ERR_LIB_UI, 104),
    ("INDEX_TOO_LARGE", lib.ERR_LIB_UI, 102),
    ("INDEX_TOO_SMALL", lib.ERR_LIB_UI, 103),
    ("NO_RESULT_BUFFER", lib.ERR_LIB_UI, 105),
    ("PROCESSING_ERROR", lib.ERR_LIB_UI, 107),
    ("RESULT_TOO_LARGE", lib.ERR_LIB_UI, 100),
    ("RESULT_TOO_SMALL", lib.ERR_LIB_UI, 101),
    ("SYSASSIGN_ERROR", lib.ERR_LIB_UI, 109),
    ("SYSDASSGN_ERROR", lib.ERR_LIB_UI, 110),
    ("SYSQIOW_ERROR", lib.ERR_LIB_UI, 111),
    ("UNKNOWN_CONTROL_COMMAND", lib.ERR_LIB_UI, 106),
    ("UNKNOWN_TTYGET_ERRNO_VALUE", lib.ERR_LIB_UI, 108),
    ("USER_DATA_DUPLICATION_UNSUPPORTED", lib.ERR_LIB_UI, 112),
    ("BAD_IP_ADDRESS", lib.ERR_LIB_X509V3, 118),
    ("BAD_OBJECT", lib.ERR_LIB_X509V3, 119),
    ("BN_DEC2BN_ERROR", lib.ERR_LIB_X509V3, 100),
    ("BN_TO_ASN1_INTEGER_ERROR", lib.ERR_LIB_X509V3, 101),
    ("DIRNAME_ERROR", lib.ERR_LIB_X509V3, 149),
    ("DISTPOINT_ALREADY_SET", lib.ERR_LIB_X509V3, 160),
    ("DUPLICATE_ZONE_ID", lib.ERR_LIB_X509V3, 133),
    ("EMPTY_KEY_USAGE", lib.ERR_LIB_X509V3, 169),
    ("ERROR_CONVERTING_ZONE", lib.ERR_LIB_X509V3, 131),
    ("ERROR_CREATING_EXTENSION", lib.ERR_LIB_X509V3, 144),
    ("ERROR_IN_EXTENSION", lib.ERR_LIB_X509V3, 128),
    ("EXPECTED_A_SECTION_NAME", lib.ERR_LIB_X509V3, 137),
    ("EXTENSION_EXISTS", lib.ERR_LIB_X509V3, 145),
    ("EXTENSION_NAME_ERROR", lib.ERR_LIB_X509V3, 115),
    ("EXTENSION_NOT_FOUND", lib.ERR_LIB_X509V3, 102),
    ("EXTENSION_SETTING_NOT_SUPPORTED", lib.ERR_LIB_X509V3, 103),
    ("EXTENSION_VALUE_ERROR", lib.ERR_LIB_X509V3, 116),
    ("ILLEGAL_EMPTY_EXTENSION", lib.ERR_LIB_X509V3, 151),
    ("INCORRECT_POLICY_SYNTAX_TAG", lib.ERR_LIB_X509V3, 152),
    ("INVALID_ASNUMBER", lib.ERR_LIB_X509V3, 162),
    ("INVALID_ASRANGE", lib.ERR_LIB_X509V3, 163),
    ("INVALID_BOOLEAN_STRING", lib.ERR_LIB_X509V3, 104),
    ("INVALID_CERTIFICATE", lib.ERR_LIB_X509V3, 158),
    ("INVALID_EMPTY_NAME", lib.ERR_LIB_X509V3, 108),
    ("INVALID_EXTENSION_STRING", lib.ERR_LIB_X509V3, 105),
    ("INVALID_INHERITANCE", lib.ERR_LIB_X509V3, 165),
    ("INVALID_IPADDRESS", lib.ERR_LIB_X509V3, 166),
    ("INVALID_MULTIPLE_RDNS", lib.ERR_LIB_X509V3, 161),
    ("INVALID_NAME", lib.ERR_LIB_X509V3, 106),
    ("INVALID_NULL_ARGUMENT", lib.ERR_LIB_X509V3, 107),
    ("INVALID_NULL_VALUE", lib.ERR_LIB_X509V3, 109),
    ("INVALID_NUMBER", lib.ERR_LIB_X509V3, 140),
    ("INVALID_NUMBERS", lib.ERR_LIB_X509V3, 141),
    ("INVALID_OBJECT_IDENTIFIER", lib.ERR_LIB_X509V3, 110),
    ("INVALID_OPTION", lib.ERR_LIB_X509V3, 138),
    ("INVALID_POLICY_IDENTIFIER", lib.ERR_LIB_X509V3, 134),
    ("INVALID_PROXY_POLICY_SETTING", lib.ERR_LIB_X509V3, 153),
    ("INVALID_PURPOSE", lib.ERR_LIB_X509V3, 146),
    ("INVALID_SAFI", lib.ERR_LIB_X509V3, 164),
    ("INVALID_SECTION", lib.ERR_LIB_X509V3, 135),
    ("INVALID_SYNTAX", lib.ERR_LIB_X509V3, 143),
    ("ISSUER_DECODE_ERROR", lib.ERR_LIB_X509V3, 126),
    ("MISSING_VALUE", lib.ERR_LIB_X509V3, 124),
    ("NEED_ORGANIZATION_AND_NUMBERS", lib.ERR_LIB_X509V3, 142),
    ("NEGATIVE_PATHLEN", lib.ERR_LIB_X509V3, 168),
    ("NO_CONFIG_DATABASE", lib.ERR_LIB_X509V3, 136),
    ("NO_ISSUER_CERTIFICATE", lib.ERR_LIB_X509V3, 121),
    ("NO_ISSUER_DETAILS", lib.ERR_LIB_X509V3, 127),
    ("NO_POLICY_IDENTIFIER", lib.ERR_LIB_X509V3, 139),
    ("NO_PROXY_CERT_POLICY_LANGUAGE_DEFINED", lib.ERR_LIB_X509V3, 154),
    ("NO_PUBLIC_KEY", lib.ERR_LIB_X509V3, 114),
    ("NO_SUBJECT_DETAILS", lib.ERR_LIB_X509V3, 125),
    ("OPERATION_NOT_DEFINED", lib.ERR_LIB_X509V3, 148),
    ("OTHERNAME_ERROR", lib.ERR_LIB_X509V3, 147),
    ("POLICY_LANGUAGE_ALREADY_DEFINED", lib.ERR_LIB_X509V3, 155),
    ("POLICY_PATH_LENGTH", lib.ERR_LIB_X509V3, 156),
    ("POLICY_PATH_LENGTH_ALREADY_DEFINED", lib.ERR_LIB_X509V3, 157),
    ("POLICY_WHEN_PROXY_LANGUAGE_REQUIRES_NO_POLICY", lib.ERR_LIB_X509V3, 159),
    ("SECTION_NOT_FOUND", lib.ERR_LIB_X509V3, 150),
    ("UNABLE_TO_GET_ISSUER_DETAILS", lib.ERR_LIB_X509V3, 122),
    ("UNABLE_TO_GET_ISSUER_KEYID", lib.ERR_LIB_X509V3, 123),
    ("UNKNOWN_BIT_STRING_ARGUMENT", lib.ERR_LIB_X509V3, 111),
    ("UNKNOWN_EXTENSION", lib.ERR_LIB_X509V3, 129),
    ("UNKNOWN_EXTENSION_NAME", lib.ERR_LIB_X509V3, 130),
    ("UNKNOWN_OPTION", lib.ERR_LIB_X509V3, 120),
    ("UNSUPPORTED_OPTION", lib.ERR_LIB_X509V3, 117),
    ("UNSUPPORTED_TYPE", lib.ERR_LIB_X509V3, 167),
    ("USER_TOO_LONG", lib.ERR_LIB_X509V3, 132),
    ("AKID_MISMATCH", lib.ERR_LIB_X509, 110),
    ("BAD_SELECTOR", lib.ERR_LIB_X509, 133),
    ("BAD_X509_FILETYPE", lib.ERR_LIB_X509, 100),
    ("BASE64_DECODE_ERROR", lib.ERR_LIB_X509, 118),
    ("CANT_CHECK_DH_KEY", lib.ERR_LIB_X509, 114),
    ("CERTIFICATE_VERIFICATION_FAILED", lib.ERR_LIB_X509, 139),
    ("CERT_ALREADY_IN_HASH_TABLE", lib.ERR_LIB_X509, 101),
    ("CRL_ALREADY_DELTA", lib.ERR_LIB_X509, 127),
    ("CRL_VERIFY_FAILURE", lib.ERR_LIB_X509, 131),
    ("ERROR_GETTING_MD_BY_NID", lib.ERR_LIB_X509, 141),
    ("ERROR_USING_SIGINF_SET", lib.ERR_LIB_X509, 142),
    ("IDP_MISMATCH", lib.ERR_LIB_X509, 128),
    ("INVALID_ATTRIBUTES", lib.ERR_LIB_X509, 138),
    ("INVALID_DIRECTORY", lib.ERR_LIB_X509, 113),
    ("INVALID_DISTPOINT", lib.ERR_LIB_X509, 143),
    ("INVALID_FIELD_NAME", lib.ERR_LIB_X509, 119),
    ("INVALID_TRUST", lib.ERR_LIB_X509, 123),
    ("ISSUER_MISMATCH", lib.ERR_LIB_X509, 129),
    ("KEY_TYPE_MISMATCH", lib.ERR_LIB_X509, 115),
    ("KEY_VALUES_MISMATCH", lib.ERR_LIB_X509, 116),
    ("LOADING_CERT_DIR", lib.ERR_LIB_X509, 103),
    ("LOADING_DEFAULTS", lib.ERR_LIB_X509, 104),
    ("METHOD_NOT_SUPPORTED", lib.ERR_LIB_X509, 124),
    ("NAME_TOO_LONG", lib.ERR_LIB_X509, 134),
    ("NEWER_CRL_NOT_NEWER", lib.ERR_LIB_X509, 132),
    ("NO_CERTIFICATE_FOUND", lib.ERR_LIB_X509, 135),
    ("NO_CERTIFICATE_OR_CRL_FOUND", lib.ERR_LIB_X509, 136),
    ("NO_CERT_SET_FOR_US_TO_VERIFY", lib.ERR_LIB_X509, 105),
    ("NO_CRL_FOUND", lib.ERR_LIB_X509, 137),
    ("NO_CRL_NUMBER", lib.ERR_LIB_X509, 130),
    ("PUBLIC_KEY_DECODE_ERROR", lib.ERR_LIB_X509, 125),
    ("PUBLIC_KEY_ENCODE_ERROR", lib.ERR_LIB_X509, 126),
    ("SHOULD_RETRY", lib.ERR_LIB_X509, 106),
    ("UNABLE_TO_FIND_PARAMETERS_IN_CHAIN", lib.ERR_LIB_X509, 107),
    ("UNABLE_TO_GET_CERTS_PUBLIC_KEY", lib.ERR_LIB_X509, 108),
    ("UNKNOWN_KEY_TYPE", lib.ERR_LIB_X509, 117),
    ("UNKNOWN_NID", lib.ERR_LIB_X509, 109),
    ("UNKNOWN_PURPOSE_ID", lib.ERR_LIB_X509, 121),
    ("UNKNOWN_SIGID_ALGS", lib.ERR_LIB_X509, 144),
    ("UNKNOWN_TRUST_ID", lib.ERR_LIB_X509, 120),
    ("UNSUPPORTED_ALGORITHM", lib.ERR_LIB_X509, 111),
    ("WRONG_LOOKUP_TYPE", lib.ERR_LIB_X509, 112),
    ("WRONG_TYPE", lib.ERR_LIB_X509, 122),
]
